# The BASIC programming language turns 60
## Easy-to-use language that drove Apple, TRS-80, IBM, and Commodore PCs debuted in 1964.
## Information:

+ Link: https://arstechnica.com/gadgets/2024/05/the-basic-programming-language-turns-60/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 01 May 2024, 16:17
+ Date scraped: 01 May 2024, 18:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/05/basic_apple_2-760x380.jpg)



Sixty years ago, on May 1, 1964, at [4 am in the morning](https://www.dartmouth.edu/basicfifty/basic.html), a quiet revolution in computing began at Dartmouth College. That's when mathematicians John G. Kemeny and Thomas E. Kurtz successfully ran the first program written in their newly developed BASIC (Beginner's All-Purpose Symbolic Instruction Code) programming language on the college's General Electric GE-225 mainframe.


Little did they know that their creation would go on to democratize computing and inspire generations of programmers over the next six decades.


What is BASIC?
--------------


In its most traditional form, BASIC is an [interpreted](https://en.wikipedia.org/wiki/Interpreter_(computing)) programming language that runs line by line, with line numbers. A typical program might look something like this:



> 10 PRINT "WHAT IS YOUR NAME?"
> 
> 
> 20 INPUT N$
> 
> 
> 30 PRINT "HELLO, ";N$
> 
> 


Programs could jump between lines using commands like GOTO, which often led to simple looping programs created by beginners that would fill the screen with repeating words. Or one could quickly write a program that counted upward toward infinity like this:



> 10 LET X=X+1
> 
> 
> 20 PRINT X
> 
> 
> 30 GOTO 10
> 
> 


Today, most programming languages use different types of structural paradigms (such as functions and object-oriented programming), but the easy-to-grasp syntax of BASIC, with its plain English keywords, proved popular and easy to use for beginners.


The journey to BASIC
--------------------


[Before](https://www.howtogeek.com/825555/where-did-the-term-computer-user-come-from/) early computers became small, inexpensive, and "personal," they were difficult to use. At first, programming a computer involved literally connecting wires, then flipping switches, and even punching paper cards. Over time, engineers [developed ways](https://www.vintagecomputing.com/index.php/archives/2580/vcg-anthology-the-evolution-of-computer-displays#more-2580) to abstract away low-level programming operations with a more friendly interface. That's where programming languages come in.


[![A brochure for the GE 210 computer from 1964. BASIC's creators used a similar computer four years later to develop the programming language.](https://cdn.arstechnica.net/wp-content/uploads/2024/05/GE_210_advertisement-640x480.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/05/GE_210_advertisement.jpg) / A brochure for the GE 210 computer from 1964. BASIC's creators used a similar computer four years later to develop the programming language.[GE / Wikipedia](https://en.wikipedia.org/wiki/GE-200_series#/media/File:GE_210_advertisement.jpg)


Prior to BASIC, programming languages like [Fortran](https://en.wikipedia.org/wiki/Fortran), [Algol](https://en.wikipedia.org/wiki/ALGOL), and [COBOL](https://en.wikipedia.org/wiki/COBOL) proved complex and were primarily used by professionals. Kemeny and Kurtz saw a need for amateurs who were not dedicated computer engineers to be able to use computers as well. Their journey to create a more user-friendly language began in 1956 with Dartmouth Simplified Code ([DARSIMSCO](https://en.wikipedia.org/wiki/DARSIMCO)), followed by the Dartmouth Oversimplified Programming Experiment ([DOPE](https://en.wikipedia.org/wiki/Dartmouth_Oversimplified_Programming_Experiment)). While DOPE proved too simple to be of much use, the lessons learned from these projects informed the development of BASIC, which started in 1963.


In the same year, Kemeny applied for a National Science Foundation grant to bring a [GE-225 computer](https://ed-thelen.org/comp-hist/GE225.html) to Dartmouth and build the first fully functional general-purpose time-sharing system. Despite the grant referees' doubts about his plan to accomplish the work with a group of undergraduates, Kemeny secured the funding.


Together with Kurtz and a group of undergraduate students, Kemeny built a time-sharing system to open computer access to all at Dartmouth. The simplicity and power of BASIC quickly made it a favorite among students and faculty alike.


BASIC goes PC
-------------


[![The cover of "The Applesoft Tutorial" BASIC manual that shipped with the Apple II computer starting in 1981.](https://cdn.arstechnica.net/wp-content/uploads/2024/05/apple2basic_hero-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/05/apple2basic_hero.jpg) / The cover of "The Applesoft Tutorial" BASIC manual that shipped with the Apple II computer starting in 1981.[Benj Edwards](https://x.com/benjedwards/status/1484173426449260544)


As part of the deal to buy the GE 225 computer, Kemeny, Kurtz, and others had earlier built a [time sharing operating system](https://en.wikipedia.org/wiki/Dartmouth_Time_Sharing_System) for General Electric. BASIC running on this operating system allowed colleges, high schools, and individuals across the country to dial into mainframe computers and write programs using the language. The impact of BASIC began to extend far beyond Dartmouth's campus.


In 1975, Paul Allen and Bill Gates adapted the language for personal computers like the [Altair 8800](https://en.wikipedia.org/wiki/Altair_8800), expanding its reach to a new audience of small computer owners and founding Microsoft in the process. In 1976, Steve Wozniak [developed a BASIC interpreter from scratch](https://gizmodo.com/how-steve-wozniak-wrote-basic-for-the-original-apple-fr-1570573636) for the Apple I using self-taught methods and minimal resources. This became [Integer BASIC](https://en.wikipedia.org/wiki/Integer_BASIC) for the Apple II a year later, and BASIC (as [Applesoft BASIC](https://en.wikipedia.org/wiki/Applesoft_BASIC)) remained a key part of the Apple II throughout the platform's lifespan.


In the late 1970s and early 1980s, BASIC continued its prominent role as a programming interface and quasi-operating system for popular home computers such as the [Atari 800](https://www.fastcompany.com/90432140/how-atari-took-on-apple-in-the-1980s-home-pc-wars), TRS-80, Commodore VIC-20, Commodore 64, TI-99/4A, [BBC Micro](https://arstechnica.com/gadgets/2023/11/bbc-basic-keeps-evolving-and-now-you-can-run-it-on-nearly-any-platform/), and the IBM PC, where it either came preinstalled in ROM as part of the operating system or shipped as an easily accessible programming environment. Early computer magazines such as Compute! [printed BASIC code listings](https://arstechnica.com/staff/2018/11/first-encounter-compute-magazine-and-its-glorious-tedious-type-in-code/) that could be typed in line by line.


BASIC today
-----------


Today, BASIC remains popular in hobbyist retrocomputing circles, but few use it as a practical language. And yet it never truly died out—instead, it continued to evolve.


Many other [BASIC dialects](https://en.wikipedia.org/wiki/BASIC#Post-1990_versions_and_dialects) exist today for different platforms, but some of Microsoft's are most commonly used. After Microsoft's [GW-BASIC](https://en.wikipedia.org/wiki/GW-BASIC) and [QuickBasic](https://en.wikipedia.org/wiki/QuickBASIC), descendants of BASIC such as [Visual Basic](https://www.theregister.com/2023/03/28/nostalgic_for_basic/), [Visual Basic for Applications](https://en.wikipedia.org/wiki/Visual_Basic_for_Applications) (VBA), and [Microsoft Small Basic](https://smallbasic-publicwebsite.azurewebsites.net/) live on. Visual Basic, introduced by Microsoft in 1991, became a popular choice for developing Windows applications, while VBA is widely used for scripting and automation in Microsoft Office applications. Microsoft Small Basic, [released in 2008](https://arstechnica.com/information-technology/2008/11/yet-another-programming-language-from-microsoft-small-basic/), serves as an educational tool for teaching programming concepts to beginners.


Meanwhile, other modern languages, such as [Python](https://en.wikipedia.org/wiki/Python_(programming_language)) and [JavaScript](https://en.wikipedia.org/wiki/JavaScript), have taken on roles similar to those once filled by BASIC. These languages prioritize simplicity, readability, and ease of use, making them popular choices for introductory programming courses and rapid application development.


Despite the decline in its practical use, BASIC's legacy lives on through its influence on subsequent programming languages and its role in making computing accessible to a broader audience. As we commemorate the 60th anniversary of BASIC, let's raise a glass to Kemeny and Kurtz for empowering several generations of young computer programmers.





## Tags:


### Autogenerated tags:
kemeny microsoft dartmouth kurtz
