# Serious flaws allow the hijacking of autonomous logistics robots used in hospitals
## The now patched JekyllBot:5 vulnerabilities in Aethon TUG robots expose three communications interfaces, two APIs, and a websocket interface.
## Information:

+ Link: https://www.csoonline.com/article/3656657/serious-flaws-allow-the-hijacking-of-autonomous-logistics-robots-used-in-hospitals.html
+ Source: CSO
+ Author: Lucian Constantin
+ Date published: 12 April 2022, 10:30
+ Date scraped: 19 April 2022, 11:01

## Article:
![Main article image](https://images.idgesg.net/images/article/2019/06/cso_botnets_robots_by_tampatra_gettyimages-958007764blue_binary_matrix_by_bannosuke_gettyimages-687353118_2400x1600-100800407-large.jpg?auto=webp&quality=85,70)


Organizations are adopting IoT solutions to automate repetitive and time-consuming tasks in their facilities and hospitals are no different. While robots and other devices can free and improve the efficiency of valuable human resources, they can also introduce risks that organizations have never previously had to deal with.

This is highlighted today by the disclosure of five serious vulnerabilities in Aethon TUG, a line of mobile autonomous robots designed to haul food, medication, lab specimens and other supplies across facilities. TUGs, which have been deployed in hospitals around the world, use sensors and cameras to navigate hallways and can interact with elevators and automatic doors through Wi-Fi.

## **The JekyllBot:5 vulnerabilities**

The flaws were discovered by researchers from healthcare IoT security firm Cynerio during an engagement in a customer hospital. Analyzing some anomalies in network traffic from an elevator led them to a portal that was used to monitor and manage TUG robots deployed inside the hospital and included layout maps and video feeds from the robots. Analysis of this fleet management portal called the TUG Home Base server revealed five separate security issues and attack vectors. The researchers dubbed them JekyllBot:5.

The server exposes three communication interfaces, a web-based API (v3) running on port 8081, a websocket interface that's used to send commands to the robots on port 8080 and a webservice and older API (v2) running on the standard HTTP port 80.

"If either of the latter two interfaces on the above list (80 and 8080) were open to an attacker, this could have enabled a total takeover of the system and its robots due to the vulnerabilities enumerated in this document," the researchers said in [their report](https://www.cynerio.com/jekyllbot-5-command-center). "Blocking these ports was not enough by itself to protect against the most severe vulnerabilities that the Cynerio Live team found."

The v2 API (port 80) did not properly check for authorization when performing certain requests or actions. This could have allowed an unauthenticated attacker to add new users with administrative privileges and modify existing users. This flaw is tracked as CVE-2022-1066 and is described as a privilege escalation issue. It's rated 8.2 out of 10 (High) severity score on the CVSS scale.

 Another privilege escalation flaw with the same severity but tracked as CVE-2022-26423 was identified in the v3 API (port 8081). This flaw gives unauthenticated attackers access to hashed user passwords which could then be cracked using brute-force methods.

A critical vulnerability tracked as CVE-2022-1070 -- 9.8 CVSS score -- was in the websocket interface and stems from improper authentication between TUG Home Base server and the robots. This allows authenticated attackers to connect to the server and take full control of the robots.


[![The Leader's Tech Guide to Hybrid Work](//ntvcld-a.akamaihd.net/image/upload/w_640,h_360,c_fill,g_auto:text,f_auto,fl_lossy,e_sharpen:70/assets/90B2D5F9B4374AABBB6A2D10F94A3539.png "The Leader's Tech Guide to Hybrid Work")](https://googlechromeos.cio.com/1G2PvE1w/google-chrome-os-solutions "The Leader's Tech Guide to Hybrid Work")

aside.nativo-promo.smartphone.tablet.desktop p { font-size: 16px !important; line-height: 1.2 !important; }
aside.nativo-promo.smartphone.tablet.desktop p.post-meta { margin-top:0px !important;}
aside.nativo-promo.smartphone.tablet.desktop p.crawl-headline { font-size: 20px !important; line-height:1 !important; }

#ntvImageBox {float: left;margin-right:20px;width: 300px; height:169px; overflow:hidden;}

@media only screen and (max-width: 667px) {
#ntvImageBox {margin-right:0; margin-bottom:10px; float:none; width:100%; height:auto;}

}


"Taken to extremes, this unauthorized access could have led to an attacker manipulating the robots to say unauthorized or abusive phrases to harass patients and staff, controlling or shutting down smart elevators and doors to interfere with critical patient or operations, and even altering medicine dispensation to the point where patient care and outcomes are disrupted or jeopardized," the Cynerio researchers said in their report.

The attackers would also gain access to the robots' picture taking and video recording capabilities, allowing them to spy on vulnerable patients or staff. Since the portal exposes movement controls through a virtual joystick, attackers could also potentially crash robots into people or other sensitive medical equipment.

The last two vulnerabilities, ​​CVE-2022-27494 and CVE-2022-1059, allowed for cross-site scripting (XSS) attacks through the portal's web interface. One of them could have allowed attackers to inject malicious JavaScript code into the “Reports” tab of the Fleet Management Console that would execute an authenticated user's browser when viewed. This type of attack could have allowed attackers to hijack administrative user sessions and inject malware into users' browsers that could have potentially enabled further attacks against the facility's IT network and infrastructure.

While the TUG Home Base server is meant to be accessed over local networks, the Cynerio team found several instances of these servers that were directly exposed to the internet and notified their owners.

 ## **Remediation for JekyllBot:5 vulnerabilities**

The Cynerio team worked closely with the robot’s manufacturer Aethon and with the U.S. Cybersecurity and Infrastructure Security Agency (CISA) to coordinate the disclosure of these vulnerabilities. The vendor has released software and firmware patches to address them. The flaws impact all versions of the robots prior to version 24.

"Several patches have been applied to the robot fleets at each Aethon customer hospital, including one major patch that required replacing firmware and an operating system update for robots at some hospitals," the researchers said. "In addition, Aethon was able to update the firewalls at particular hospitals known to have vulnerable robots so that public access to the robots through the hospitals’ IP addresses was prevented as the fixes were rolled out."

Cybersecurity research in the healthcare space has been primarily focused on devices that are directly involved in monitoring patients and administering drugs, MRI and other types of scanners, whose disruption or abuse could have an immediate negative impact on patient health. However, as this report and others show, logistical tasks such as carrying items around are also increasingly automated inside hospitals and disruption of these systems can also impact the ability of staff to work efficiently or respond to emergencies. For example, last year, researchers from Armis found serious flaws in pneumatic tube systems (PTS) that are used by many hospitals to transport sensitive materials including lab specimens, blood products, tests and medications between different departments.





## Tags:
***CVE's***: CVE-2022-1066 CVE-2022-27494 CVE-2022-26423 CVE-2022-1059 CVE-2022-1070

### Autogenerated tags:
cynerio api
