# Chrome vs. Edge: Which browser is better for business?
## With web apps the new normal, the humble web browser powers the business world like never before. We take a deep dive into the two leading desktop browsers.
## Information:

+ Link: https://www.computerworld.com/article/1644988/chrome-vs-edge-best-browser-for-business.html
+ Source: Computerworld
+ Author: Preston Gralla
+ Date published: 20 May 2024, 00:00
+ Date scraped: 20 May 2024, 11:08

## Article:
![Main article image](https://www.computerworld.com/wp-content/uploads/2024/05/chrome-v-edge-antoine-rault-unsplash.jpg?quality=50&strip=all&w=1024)






What’s the most important piece of productivity software in the business world? Some might say the office suite. But if you look at the time spent actually using software, the answer may well be the web browser. It’s where people do most of their fact-finding and research.


But that’s only a start. These days, web apps like Google Docs, Gmail, Salesforce, Jira, and countless others are accessed via the browser as well. And countless software makers that offer traditional apps that you install and run on the desktop, such as Trello, Asana, Slack, and Microsoft 365 apps like Word, Excel, PowerPoint, and Outlook, also have highly capable web-based versions of their apps that are more convenient to use at times. So browsers have become your window to work as well as your window to the world.


Which is the best browser for your business? To find out, we’ve put the two most popular desktop browsers worldwide — Google Chrome and Microsoft Edge — to the test. We looked at the basics, like overall interface, speed, and HTML compatibility. Then we moved beyond that to safety and privacy, the availability of extensions, syncing data and settings across multiple devices and platforms, and extra features. We compared the tools each vendor provides for IT to deploy, manage, and configure its browser. And we looked at their built-in AI capabilities.


 
 
 






 
 

### Chrome vs. Edge: 10 comparisons


* [Overall usability](#usability)
* [Speed, system resource use, and HTML compatibility](#speed)
* [Safety and privacy](#safety)
* [Extensions](#extensions)
* [Syncing across multiple devices and platforms](#syncing)
* [AI features](#ai)
* [Extras](#extras)
* [Enterprise features](#enterprise)
* [The best browser for business overall](#best-overall)


So if you’re looking to switch your company away from its current browser, ready to kick the tires of a different browser, or just plain curious about other options, we’ve got answers for you.


Overall usability
-----------------


The best browsers don’t get in the way of web browsing, but instead make it easier with straightforward features like managing bookmarks and customizing settings. An ideal browser should fade away so the web itself takes center stage. In this section, we’ll look at each browser’s overall usability, including the interface, bookmark handling, and more.


### Chrome


When Chrome was introduced back in 2008, Google took what at the time was a radical, less-is-more approach to browser design: it put websites and their content front and center, stripping out all nonessential browser features. It was the browser equivalent of Google’s stripped-down search interface.


 
 
 






 
 

Not much has changed since then. Chrome has held to its austere ethos for all these years, and it’s served the browser well. There’s very little interface visible; it’s pretty much all content.


![chrome browser interface](https://b2b-contenthub.com/wp-content/uploads/2024/04/chrome-browser-interface-2024.png?w=1024)Chrome offers a simple, stripped-down, easy-to-use interface.




IDG


As for features, all the usual suspects are here: click the + button at the right of your tabs to open a new tab, click the X on any tab to close it, click the star at the far right of the address bar to add it to your bookmarks, and so on. To manage your Google account, to add another Google account, or to use account-related features such as syncing, click the user icon just to the right of the address bar — the icon is your picture or initial if you’re logged in, or a generic person’s silhouette if not.



And for more settings and features, click the three-dot icon at the far right of the screen to bring up a menu for viewing and managing your bookmarks, viewing your history and downloads, launching a private incognito window, managing your extensions, digging deep into all your settings, and more.


### Edge


The Edge browser has been around in some form since 2015. The first version, based on Microsoft’s own EdgeHTML engine, failed to interest either users or developers; it never captured even 5% of the desktop browser market. In 2019, Microsoft threw in the towel on its homegrown browser, focusing instead on a completely new version of Edge based on the Google-launched [open-source Chromium project](https://www.computerworld.com/article/1717405/googles-chromium-browser-explained.html) that also powers Chrome.


The new Edge is everything that the old Edge wasn’t: simple, fast, and stripped-down. The old Edge, now known as Edge Legacy, was filled with countless unnecessary features: an e-reader and e-book manager, a way to mark up websites and share the markup with others, and lots of other useless frippery. With Chromium Edge, all that goes away.


The result Is a browser with a streamlined interface very much like Chrome’s, although it does have more icons to catch your eye.  Web content takes center stage. Opening and closing tabs works the way you expect it to, and you click the star at the right end of the address bar to add a site to your favorites.


 
 
 






 
 

![edge browser interface](https://b2b-contenthub.com/wp-content/uploads/2024/04/edge-browser-interface-2024.png?w=1024)Since switching to Chromium, Edge sports a stripped-down, Chrome-like interface.




IDG


To the right of the address bar are an icon that will let you control and customize your extensions, if you use any; the Favorites manager icon (a star with three horizontal lines); a Collections icon (a + sign over documents or folders), a feature that I’ll cover in more detail in the “Extras” section of this article; a “Browsers Essentials” icon in the shape of a heart that leads to tools such as a power-saving option; and a three-dot icon that launches a menu for viewing your history and downloads, managing your extensions, launching a new private browsing window, adjusting your settings, and so on.


To the right of that is a Copilot icon that confusingly launches the Edge sidebar, a pane that includes not only Microsoft’s genAI tool, but also a host of other icons that let you play games, shop, launch Outlook, and more. For details on working with the Edge sidebar, see “[11 top productivity tips for Microsoft Edge](https://www.computerworld.com/article/1613111/microsoft-edge-productivity-tips.html).”



### The best browser for overall usability


This one’s a tossup. Chrome and Edge, based on the same Chromium code, are streamlined, simple, easy-to-use browsers. Edge adds a marginal bit of busyness, but overall it’s as clean and clear as Chrome.


Speed, system resource use, and HTML compatibility
--------------------------------------------------


No matter how many bells and whistles a browser has, and no matter how elegant or useful the design, if it’s slow or hogs your system resources you won’t want to use it.  And if it doesn’t adhere to web standards you don’t want to use it, either.


 
 
 






 
 

So I put Chrome and Edge through a series of tests to see how each performs in speed, system resource usage, and HTML compatibility. For all the tests, I used a clean, just-launched version of each browser free of extensions, running on the same Windows PC. I didn’t sign into any websites. I ran each test three times and averaged the results.


### Speed tests


To test speed of loading pages, browsing, and using web apps, I chose three tests.



[**JetStream 2**](https://browserbench.org/JetStream/) is a JavaScript and WebAssembly suite that tests how browsers react to advanced web applications. According to its website, “It rewards browsers that start up quickly, execute code quickly, and run smoothly.” It’s especially useful for measuring how well a browser performs handling advanced workloads.


**[WebXPRT 4](https://www.principledtechnologies.com/benchmarkxprt/webxprt/)** uses HTML5- and JavaScript-based scenarios to test browser performance, including for photo editing, organizing photos using artificial intelligence, calculating stock option prices, encrypting notes, scanning with OCR, creating graphs, and doing homework online.


 
 
 






 
 

**[Speedometer 3.0](https://browserbench.org/Speedometer3.0/)** measures how responsive browsers are overall to running web applications.


For all three tests, the higher the number, the better the browser performance.


The results? A mixed bag. Edge bested Chrome in JetStream 2, scoring 216.260 to Chrome’s 194.260, and eked out a win in WebXPRT 4 at 184 to Chrome’s 179. Chrome, meanwhile, beat Edge in the Speedometer test, at 236 to 213.


#### Browser benchmarking results




|  | Chrome | Edge |
| --- | --- | --- |
| JetStream 2 | 194.462 | 216.260 |
| WebXPRT 4 | 179 | 184 |
| Speedometer 3.0 | 236 | 213 |

 *Higher numbers are better*


What does all this mean in the real world? Perhaps not much. I didn’t notice any practical difference between them during the course of my normal web browsing. However, it’s possible that one browser might be speedier than the others in one website or app but not another.


 
 
 






 
 

So if performance is absolutely necessary for you for a particular website, I recommend you try both on that one site, and make your decision based on that. And if you frequently put heavy loads on your browser, Edge’s better performance on the JetStream 2 test might signal better performance.


### RAM and CPU tests


I also tested how much RAM and CPU each browser used by loading ten websites into different tabs, waiting a minute, then using Windows Task Manager to measure the system resources each browser used. In these tests, lower numbers are better.


Here Edge used slightly less RAM and CPU than Chrome, averaging 1.9GB of RAM and 5% CPU usage, followed by Chrome with 2GB RAM and 7% CPU use. I also found that over five minutes, Edge’s CPU usage dropped considerably, to as low as 1%. Chrome’s dropped as well, but only got as low as 3%.


That doesn’t add up to a dramatic difference. Still, if you’re multitasking using many different applications in addition to your browser, you may well notice a slowdown in Chrome versus Edge. And in those situations, you’d likely do better using Edge.


 
 
 






 
 

### HTML tests


Finally, to test HTML compatibility, I used what is generally accepted as the gold standard of HTML testing, [**html5test.co**](https://html5test.co/).


Edge and Chrome were tied in this test, each scoring 581 out of a possible 595 and supporting the exact same web standards.


### The best browser for speed, system resource use, and HTML compatibility


Edge ekes out a slight victory over Chrome here. Edge and Chrome clocked close to identically in the various speed tests and scored the same on the HTML test. But in my tests, Edge used less system resources.


Safety and privacy
------------------


The web isn’t a safe place. There’s malware out there, drive-by-download sites, and plenty of sites that are just plain up to no good. And that’s not all. Even the trustworthy sites may be tracking your online activity and sharing it with others without your knowledge or consent. So we compared how the browsers stack up for security and privacy.


 
 
 






 
 

### Chrome


Chrome has most of the safety and privacy features and settings you’d expect in a browser, including stopping malware and drive-by downloads and the ability to limit or stop cookies being placed on your PC. (Its [Incognito mode](https://www.computerworld.com/article/3356840/how-to-go-incognito-in-chrome-firefox-safari-and-edge.html), like similar features in other browsers, lets you turn off browsing history on your local computer but doesn’t actually allow you to browse the web anonymously, as is widely believed.) You get to them all in the “Privacy and security” section of Settings.


Here you can customize your settings by controlling websites’ ability to access your camera or microphone, for example, or by blocking third-party cookies. Third-party cookies are those put on your computer by a site other than the one you’re currently visiting. They’re typically used to track your behavior across sites. Chrome also lets you send a “Do Not Track” request to websites. However, while that may sound useful, it’s not particularly effective, because websites don’t have to adhere to your request.


Chrome does, though, have a “Safety check” feature that examines your browser settings for possible privacy and safety holes, and looks for potentially harmful extensions and possible compromised passwords. It warns you if it finds any issues and makes recommendations about how to fix them. You’ll have to be signed into Chrome to get the most out of it.


![chrome privacy and security settings](https://b2b-contenthub.com/wp-content/uploads/2024/04/chrome-safety-check-2024.png?w=1024)Chrome’s “Safety check” is a useful tool for finding potentially compromised, reused, and weak passwords.




IDG


For example, it found that 114 web passwords of mine had been compromised, and listed every one of them so I could change them. In addition, it warned that I had 217 weak passwords and recommended I change them — and listed them all. And it pointed out that I had 356 reused passwords and should create unique ones, and again, it listed them all.


 
 
 






 
 

There’s also an “Enhanced protection” option that’s found under *Settings > Privacy and security > Security: Safe Browsing (protection from dangerous sites) and other security settings*. When enabled, it analyzes websites and downloads in real time and warns you of anything suspicious — but the privacy conscious should note that it sends “the URLs of sites you visit and a small sample of page content, downloads, extension activity, and system information to Google Safe Browsing to check if they’re harmful” and ties that information to your Google account if you’re logged in.


### Edge


Like Chrome, Edge stops malware and drive-by downloads, and it lets you limit or stop cookies being placed on your PC; control the default behavior when websites request access to your camera, microphone, location; use a secure DNS provider; and so on. It also has [an incognito mode called InPrivate](https://www.computerworld.com/article/3356840/how-to-go-incognito-in-chrome-firefox-safari-and-edge.html) that disables browsing history on your local computer only, and it will send a “Do Not Track” request, although as I’ve explained, its usefulness is suspect.


Most notable about Edge’s privacy protections is tracking prevention, which blocks ad providers from tracking you from website to website. That makes it more difficult for companies like Google, Facebook, and others to build comprehensive profiles of your activities and interests.


![edge privacy settings](https://b2b-contenthub.com/wp-content/uploads/2024/04/edge-privacy-settings-2024.png)Edge’s tracking prevention feature makes it difficult for companies to build comprehensive profiles of your activities and interests.




IDG


By default, tracking prevention is turned on. But you can customize how it works, making it less or more restrictive depending on how much privacy you would like when browsing the web and how much you want to see ads and content that mirror your interests. To do it, click the three-dot icon at the top right of Edge’s screen and select *Settings > Privacy, search, and services*.


 
 
 






 
 

You have three tracking prevention choices:


* **Basic** allows most trackers and blocks only those that Microsoft considers harmful. You’ll have less privacy but will be more likely to see personalized ads and content.
* **Balanced** is the default setting; it blocks more trackers than the Basic setting. Ads and content won’t be as personalized, but sites should still work properly.
* **Strict** blocks the majority of trackers from all websites, as well as harmful ads. This gives you the most privacy, and ads and content will have minimal personalization. Parts of websites may not work properly when you choose this setting.


You can customize tracking prevention further by clicking *Exceptions*. That will let you specify sites on which you’d like to allow all trackers. Edge also allows you to see which ad trackers it has blocked. Click *Blocked trackers* to see them.


You can also see which trackers have been blocked on any website you’re currently visiting and fine-tune your protection on a site-by-site basis. To do it, click the lock icon to the left of the URL in the address bar, and you’ll see information such as the number of cookies put on your device by the site, trackers blocked and so on. Click the cookies icon to see each individual cookie. You’ll also be able to remove any cookies and block any others the next time you visit the site.


However, Microsoft also uses Edge to collect diagnostic data to, in the words of Microsoft, “keep Microsoft Edge secure, up to date and performing as expected.” That worries some people, while for others, it’s no problem at all. So you’ll have to decide whether it’s worrisome. You can control what data Edge gathers and eliminate some of it. For details, see Microsoft’s “[Microsoft Edge, browsing data, and privacy](https://support.microsoft.com/en-us/windows/microsoft-edge-browsing-data-and-privacy-bb8174ba-9d73-dcf2-9b4a-c582b4e640dd)” support page.


Edge also has a feature called Browser Essentials that displays a pane that includes a Safety section that tells you how many websites you’ve visited and how many downloads Edge has scanned for safety in the last 30 days, as well as how many risks it claims have been prevented and how many items have been blocked. I found it useless, little more than a bit of PR puffery, given that it has no safety features you can turn on or off.


### The best browser for safety and privacy


Each browser offers the same basic protections, But Edge goes beyond the basics with its blocking of trackers and related technologies, and the ability to customize how each works. So it gets the nod here.


Extensions
----------


A browser by itself is certainly useful, but it can be powered up and customized by extensions. These browser add-ons can do an almost mind-boggling number of things. Want to block ads, use a secure password manager, edit graphics, read PDF files, handle your mail better, or do thousands of other things? Then extensions are for you.


In this section we look at how rich each browser’s add-on ecosystem is, and how easy it is to install, use, manage, and uninstall them.


### Chrome


Chrome’s rise to become the most popular browser in the world was fueled in part by its support for extensions and the vast number of add-ons available for it. There’s no definitive answer for the total number, although [one analysis put it at 188,620 as of early 2024](https://truelist.co/blog/google-chrome-statistics/).


More important than the total number, though, is whether they’re useful. And by any measure, Chrome extensions are exceedingly useful. You typically install them via the [Chrome Web Store](https://chrome.google.com/webstore/category/extensions), although you can also install them directly from a website. But take care that the site is a reputable one. Google does work to make sure the extensions in its store are free of malware, so whenever you install one outside that store, you may be taking a chance.


To install from the Chrome Web Store, when you’re reading a description of an extension, click the *Add to Chrome* button on the upper right of the screen. You’ll get a notification about the access it will have to your PC, for example, “Read and change all your data on the websites you visit” or “Display notifications.” If you decide to go ahead, click *Add extension*. After a short time, the extension will install, and you’ll see its icon on the upper right of the screen. Click the icon to use it and to change any of its settings.


When you’ve installed more than one extension, instead of seeing icons for each separate extension, you’ll see a single icon of a puzzle piece. Click it to get access to all your extensions, to use their features, change their options, and remove them from Chrome. From here you can also choose to pin icons for individual extensions to the top right of Chrome, next to the puzzle piece icon.


You can also manage and remove them by clicking the puzzle piece icon and selecting *Manage Extensions*.. This takes you to the Extensions page, where you can find more details about any extension, adjust its settings, remove it, or disable it — which turns it off while keeping it installed. That way, you can easily re-enable it without having to reinstall it.


![chrome extensions manager](https://b2b-contenthub.com/wp-content/uploads/2024/04/chrome-extensions-2024.png)Here’s where you’ll manage your Chrome extensions.




IDG


### Edge


In the pre-Chromium days of Edge, one of the browser’s many problems was how few extensions it had. By the time the new Chromium version of Edge was released, the old version had fewer than 300 extensions, not tens of thousands like Chrome.


With the move to Chromium, all that has changed. That’s because Edge can now use extensions built for Chrome. When the Chromium-based version of Edge was released, Microsoft warned people that some Chrome extensions might not work on Edge, notably those that rely on Google account functionality to sign in or sync data or those that rely on companion software on your PC. However, I’ve been using the Chromium version of Edge since its introduction in mid-January of 2020 and haven’t come across a single one that didn’t work, including multiple add-ons that require signing into a Google account.


Microsoft has an extension store for the Chromium version of Edge. Get to it by clicking the three-dot icon at the top right of Edge, selecting *Extensions* and clicking *Get extensions for Microsoft Edge*. The Edge Add-ons store doesn’t have nearly as many extensions as the Chrome Web Store. But that’s no problem, because you can also install extensions into Edge directly from the Chrome Web Store.


Unlike Chrome, Edge shows each extension’s icon at the top right of the screen. As with Chrome, click any add-on’s icon to manage, uninstall or select what features you want to use. You can also manage and remove them by clicking the three-dot icon at the top right of Edge and selecting *Extensions*. As with Chrome, from here you can disable and enable extensions as well.


![edge extensions manager](https://b2b-contenthub.com/wp-content/uploads/2024/04/edge-extensions-2024.png)Edge’s screen for managing extensions.




IDG


### The best browser for extensions


In theory, some Chrome extensions might not run in Edge, although I’ve yet to come across one or hear of one that doesn’t work. So I’ll rate Chrome and Edge a tie in this category.


Syncing across multiple devices and platforms
---------------------------------------------


We live in a business world in which we use multiple devices — desktop PCs and laptops running Windows and macOS, as well as smartphones and tablets running iOS and Android. We want our browser settings, favorites, passwords, and other data to be the same and sync on any device.


So I tested how well each browser synced data on two Windows PCs, a Mac, and Android and iOS devices.


### Chrome


Chrome does a superb job not just of syncing data across all of your devices, but giving you a great deal of control over what gets synced. So you can sync data on some devices and not others. And you can customize exactly what gets synced.


To do all that, you’ll need to have a Google account and sign into it on Chrome. Once you do that, click your Google account icon (your photo or initials) at the top right of your screen and choose *Turn on sync* from the menu that appears. On the next screen, choose *Yes, I’m in*. To customize what syncs and get more information about syncing, to go *Settings > Sync and Google services*. You’ll come to a page that gives you thorough control over syncing. It lets you manage what you sync, review your synced data, and encrypt your synced data.


Click *Manage what you sync* and you’ll come to the full list, including apps, bookmarks, extensions, history, browser settings, themes, open tabs, passwords, addresses and phone numbers, and payment methods for Google Pay. To sync them all, select *Sync everything*. To fine-tune it, click *Customize sync* and move the slider to off next to anything you don’t want to sync.


![chrome sync manager](https://b2b-contenthub.com/wp-content/uploads/2024/04/chrome-manage-sync-2024.png?w=1024)Managing what you sync in Chrome.




IDG


Back on the Sync and Google services page, click *Review your synced data*, and you’ll see the total number of pieces of data you’ve synced for each category — for example, 11 extensions, 489 settings, 610 passwords, and so on. However, you won’t actually see the data itself, just the totals by category. To find the data, you’ll have to spend a fair amount of time clicking around Chrome Settings, for example to count all your extensions, count all your passwords, and so on.


As for how good a job it does of syncing, there’s not much to say other than it works without a hitch. I didn’t encounter a single syncing problem. The data showed up on all devices I wanted it to and didn’t show up on devices I didn’t want it to.


### Edge


Edge doesn’t quite come up to Chrome’s standards when it comes to syncing data, although it comes close. First, the good news: It’s easy to sync data across all your devices. You’ll need a Microsoft account. Sign in, and then click the three-dot icon at the top right of Edge and select *Settings > Sync*. Click *Turn On Sync* to sync your data to other devices using Edge.


You can then choose which data to sync, including favorites, settings, addresses and contact information, passwords, extensions, browsing history, open tabs,  and more. (Note that Microsoft Collections, covered later in this article, always automatically sync, so they aren’t listed on the Sync page. We’ll have more information about Collections in the Extras section of this article.) For each category you want to sync, move the slider to On.


There’s only one thing Edge can’t do that Chrome can: You can’t see the amount of data being synced by category as you can with Chrome.


![edge manage sync](https://b2b-contenthub.com/wp-content/uploads/2024/04/edge-manage-sync-2024.png?w=1024)Edge’s syncing works well, but you can’t view the specifics of your synced data.




IDG


As with Chrome, my Edge data synced without a hitch.


### The best browser for syncing


Chrome gets the slightest of edges here. here. It gives you details about your synced data, while Edge doesn’t. If that doesn’t matter to you, though, it won’t make a difference in choosing which browser to use.


AI features
-----------


AI, particularly generative AI (genAI), isn’t just the future of computing, it’s the present as well. It can help you research, write documents, and far more. Being able to use AI in your browser is important today and will become even more vital tomorrow. So in this section we’ll look into the built-in AI capabilities of each browser.


### Chrome


As of this writing, Google is testing the use of AI in Chrome to help you write text when you’re typing into a text box on the web, and to create your own Chrome themes to customize the way the browser looks. To try them out, click the three-dot icon at the top right of the screen, then select *Settings > Experimental AI* and move the slider to On.


That leads to a screen that shows you [Chrome’s AI capabilities](https://blog.google/products/chrome/google-chrome-generative-ai-features-january-2024/), including “Help me Write” for aid with writing, “Tab organizer” to automatically create tab groups based on your open tabs, and “Create themes with AI” to design your own Chrome theme.  They’re moderately useful, at best. Expect Google to power them up and add more genAI capabilities to Chrome at some point.


### Edge


Microsoft is widely recognized as the leader in genAI, thanks to its Copilot line of products built on top of OpenAI’s powerful ChatGPT. So it’s no surprise that Copilot is built directly into Edge. To get to it, click the Copilot icon on the upper right hand of the screen. A pane appears on the right that gives you full access to Copilot, which can accomplish a wide range of tasks, particularly in helping in drafting documents and finding information on the web, although it can do more as well. A full description of its capabilities are beyond the scope of this article. To read more about it, see “[7 ways to use Microsoft Copilot right](https://www.computerworld.com/article/3712249/7-ways-to-use-microsoft-copilot-right.html).”


From inside Bing, there’s also a way to use Microsoft’s genAI graphics tool, Designer, powered by OpenAI’s DALL-E. At the top far right of the pane that appears when you click the Copilot icon, you’ll see a column of vertical icons just underneath the Copilot icon.  Click the plus sign, which is the bottommost icon. In the Search box that appears, search for **designer**, then click the icon that appears. That launches Designer. If you want to design something, such as a marketing brochure, describe it in text. Click any of the designs to customize them or download them.


![edge designer ai pane](https://b2b-contenthub.com/wp-content/uploads/2024/04/edge-designer-ai-pane-2024.png)One of Edge’s powerful genAI tools is Designer, which can perform graphic design tasks.




IDG


### The best browser for AI


Nothing could be clearer: If you want to use genAI in your browser right now, Edge is by far the better choice.


Extras
------


Browsers these days aren’t chock full of extra, proprietary features, such as being able to mark up websites, as they were in years past. And that’s a good thing, because most of those extras tended to weigh down the browser, make for a confusing interface, and not add a lot of extra value.


Still, today’s browsers do have a few worthy extras. Here are the best in Chrome and Edge. (Note that I don’t include features that both browsers have, such as being able to save tab groups, or to use a private, incognito mode.)


### Chrome


Google has taken a less-is-more approach to browser design in Chrome, and likely because of that, there aren’t a surplus of notable extras in the browser. What you see is largely what you get.


That being said, there are some good extras. Foremost is the ability to do Chromecasting — “cast” whatever is on your screen to a TV or other device with a Chromecast stick attached to it. That lets you watch streaming media on your TV rather than a computer. Edge doesn’t include this same capability built into it, although you can install an add-on that will let you do the casting.


Chrome’s password manager has one nice extra: It can generate strong passwords for you. And Chrome’s search/address bar, called Omnibox, can deliver what Google calls “rich results” that will provide answers for a search in a dropdown box rather than having to launch the search and then browse through a web page.


However, I found that feature essentially useless. Yes, it can give you sports scores ( try “celtics score”). And it can add numbers. But that’s about it. It also can give misleading information. For example, when I typed in “capital of Massachusetts” it returned mostly links to web sites, as you would expect. The only rich result it offered was Springfield — but the state capital is Boston.


Much more useful is Chrome’s built-in media player. It lets you stop and start videos and audio, jump to the next or previous track, and play the media in its own window. Especially nice is that you can control all media in all tabs simultaneously with the player. On the downside, it doesn’t let you control the volume. To get to the controller, click the small music-note icon that appears to the right of the address bar when you go to a web page and start to play music, video, or other sound.


![chrome media player](https://b2b-contenthub.com/wp-content/uploads/2024/04/chrome-media-player-2024.png)Chrome’s media controller lets you play all media in your open tabs, including stopping, starting, and more.




IDG


Chrome also has a hidden side panel that you may or may not find useful. There are only a few things you can show here, including your browsing history, your bookmarks, a list of web pages or articles you’ve put in a reading list you want to get to later, putting the current web page into “reading mode,” and doing a search.


What’s more, you have to know where to find each of these items to launch its panel. For instance, to see your reading list, you click the three-dot icon at the upper right of the screen, then select *Bookmarks and Lists > Reading List > Show Reading List*. Once the panel is visible, you can click its pin icon to place a Reading List icon at the top of the screen, and from then on you can launch the Reading List panel with a single click. But you have to go through the same process to add any of the other panels. It’s a convoluted way to access a feature that doesn’t seem terribly valuable in the first place.


Long story short: I find the side panel useless, but as the saying goes, your mileage may vary.


### Edge


Edge has what I believe to be the best single feature offered in a browser: Collections. It lets you gather web pages, images, and portions of web pages into a sidebar and organize them by categories. You can also add notes to each of your collections and copy them to the clipboard, and from there paste them into an application. I’ve found it to be an incredible productivity-booster, and I use it constantly throughout my working day.


To use it, click the *Collections* icon, a + sign inside two squares with rounded corners, at the top right of the screen. The Collections pane opens on the right as a sidebar. The first time you use Collections, it will automatically start four collections for you: Wishlist, Reading List, Video Playlist, and Cookbook. You can use any of those collections or select *Create new collection* at the top of the pane and type in a name.


To add the web page you’re on to the collection, click *Add current page*. You can drag images to the collection to add them, as well as selecting text or sections of web pages and dragging them to the collection. If you have multiple collections, you can drag images or selections to any collection in the main Collections list.


![edge collections pane](https://b2b-contenthub.com/wp-content/uploads/2024/04/edge-collections-2024.png)Edge’s Collections capability is the single best extra feature I found.




IDG


To add a note to a collection, hover your cursor over an item in the collection, click the three-dot menu that appears, and select either *Add note to item* or *Add note after item*. You can change the text formatting of any note, as well as add images to it.


You can also add web pages to a collection without actually opening the Collections pane — just right-click on a neutral area of the page and in the pop-up menu that appears, select *Add Page to Collections*, and choose the collection you want to add it to or start a new one. You can add images and selected text to a collection using the right-click menu as well.


How might you use Collections? In just about any way possible. You can set up different collections for each of your projects and store web-based research there. You can set up collections for your budgets, for marketing research, for just about anything to do with your work.


You can also easily delete collections so that you don’t get overwhelmed by your research. It’s so easy to create collections you’ll probably find yourself creating them even just for a day or two for short-term research and then deleting them.


### The best browser for extras


If you use the web for research, you’ll find Collections in Edge the best extra you can get.As for Chrome, Chromecasting is the most important extra you’ll really care about — and it’s available in Edge via an add-on, so Edge is the clear winner here.


Enterprise features
-------------------


In businesses, a browser isn’t a standalone piece of software. It’s an essential part of any company’s suite of productivity tools. So in this section we look at the things IT needs to know about each browser, including deployment, management, links to other productivity software, and more.


### Chrome


Chrome relies, to some extent, on enterprises using tools from companies other than Google (notably Microsoft) for deployment and management. Google does, however, have its own tools as well. These are the most important kinds of tools businesses can use to manage Chrome:


* **Microsoft Group Policy.** This is for businesses that use Group Policy as their primary method of managing their applications. You use group policy to manage Chrome as you would any other application.
* **Chrome Enterprise Core cloud management.** This free tool lets IT enroll and manage Chrome across Windows, macOS, and Linux using the same Google Admin console as Google Workspace and ChromeOS management. It offers information for troubleshooting and insights about how Chrome is used, with details such as device types, OS version, browser version, installed extensions and policies applied per browser. [Go here to get details and to use it](https://chromeenterprise.google/products/cloud-management/).
* **Google Admin console.** This enforces policies for users of Chrome on managed computers.
* **Third-party management tools.** These include Intune from Microsoft, as well as other endpoint management tools such as VMware Workspace One and Jamf.


With all these tools, enterprises can control permissions for browser use, such as for installing extensions. They can be based on, for example, on identity and organization units, as well as applied on a site-by-site basis. The tools also allow for the creation of block lists and allow lists for sites, apps, and content types.


Enterprises can use their normal software distribution tool for creating browser images to deploy across the enterprise. Google offers [Chrome Enterprise downloads](https://chromeenterprise.google/download/) for Windows and macOS in different file and architecture types. As for browser updates, Google recommends that enterprises keep Chrome’s auto update turned on so that it happens automatically, although it can also be managed via the tools mentioned above.


There’s also some integration between Chrome and G Suite/Google Workspace, notably allowing employees to search through their company’s Drive folders from the Chrome search box.


### Edge


Microsoft offers a wealth of tools for deploying, managing, and controlling browser use, far more than can be covered here. For a start, there’s Microsoft Group Policy and Intune. But that’s just the beginning. Microsoft 365 customers can use [Microsoft Configuration Manager](https://docs.microsoft.com/en-us/mem/configmgr/core/understand/introduction), which can [configure more than 250 policies](https://docs.microsoft.com/en-us/deployedge/microsoft-edge-policies). [FastTrack](https://learn.microsoft.com/en-us/microsoft-365/fasttrack/products-and-capabilities#the-new-microsoft-edge) offers remote deployment guidance, compatibility assistance, configuration advice, and more. There are also plenty of self-guided videos for helping with deployment and configuration on [Microsoft Mechanics on YouTube](https://www.youtube.com/playlist?list=PLXtHYVsvn_b-uXh1tMeYpT-0iD8tD3tFy).


For controlling permissions for Edge, including extension use, enterprises can use Microsoft Entra ID (formerly called Azure Active Directory) and [Microsoft Entra Conditional Access](https://docs.microsoft.com/en-us/azure/active-directory/conditional-access/). That includes not just blocking extensions, but also installing extensions automatically enterprise-wide and making sure they can’t be uninstalled. For details, see the [Microsoft Edge – Policies documentation](https://learn.microsoft.com/en-us/deployedge/microsoft-edge-policies).


There are also many security tools for Edge for enterprises, including [Microsoft Security Baselines](https://docs.microsoft.com/en-us/windows/security/threat-protection/windows-security-baselines) in the [Microsoft Security Compliance Toolkit](https://learn.microsoft.com/en-us/windows/security/operating-system-security/device-management/windows-security-configuration-framework/security-compliance-toolkit-10). Microsoft also has a wide variety of tools for deploying Edge and then configuring or restricting updates using Microsoft Edge Update policies.


There are quite a few links between Edge and Microsoft 365, including using Edge and Microsoft’s search engine Bing to do enterprise-wide searches. Edge can also be configured to show you all the Office files you’ve been recently using when you open a new tab. It can also recommend files you might want to open, based on your recent usage. [See more details](https://learn.microsoft.com/en-us/deployoffice/microsoft-search-bing) about using Edge and Bing in concert with Microsoft 365 in enterprises.


Those are just the highlights. There’s plenty more as well.


### The best browser for enterprise features


Edge comes up big here. It has the most robust set of management tools for enterprises by a mile. Chrome relies on some of those tools, although it also has several of its own as well.


The best browser for business overall
-------------------------------------


So which browser is best for your business?


Edge is the best choice for most businesses. Organizations that may have ruled out the pre-Chromium version of the browser should give the new Edge a second look. They may well be pleasantly surprised.


Edge came in first place in the majority of our categories, especially the most important ones. The browser’s tracker blocking will especially be welcomed by those who value their privacy. If you’re a Microsoft customer already using Microsoft management and deployment tools, Microsoft 365, and/or other software, choosing Edge is a no-brainer. And Edge includes the most powerful genAI tools available, while Chrome offers none.


However, Chrome is a better choice than Edge for some organizations. If you use Google Workspace, you’ll want to go with Chrome, because you’ll be able to manage all your Google software from a common console.


*This article was originally published in January 2021 and updated in May 2024.*





## Tags:


### Autogenerated tags:
microsoft google websites idg html three-dot genai apps website windows
