# Researchers Uncover Rust Supply-Chain Attack Targeting Cloud CI Pipelines
## Researchers discover a new Rust Crate Registry's software supply chain attack targeting cloud continuous integration (CI) pipelines.
## Information:

+ Link: https://thehackernews.com/2022/05/researchers-uncover-rust-supply-chain.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 20 May 2022, 10:41
+ Date scraped: 20 May 2022, 11:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjqwya89ZsCrHt5eolagNl3_SqZlUKqMy8Vcn5zkg1ivczy5RIDqmDJ-9ceXfxKRtDYYy8uG9uOBDWQ1KRC6jOfeiWd2gsKXMVXXhYp7Bd3vI4E3pW_vGg9CIaceqzsAyZ3HTH7lR9QrIxtgrGC9O0e2yfuCKkhfjoYroIHpI7Zwm0PSOKjwkSN_TlH/s728-e100/code.jpg)


A case of software supply chain attack has been observed in the Rust programming language's [crate registry](https://doc.rust-lang.org/book/ch07-01-packages-and-crates.html) that leveraged typosquatting techniques to publish a rogue library containing malware.


Cybersecurity firm SentinelOne dubbed the attack "[CrateDepression](https://www.sentinelone.com/labs/cratedepression-rust-supply-chain-attack-infects-cloud-ci-pipelines-with-go-malware/)."


Typosquatting attacks [take place](https://snyk.io/blog/typosquatting-attacks/) when an adversary mimics the name of a popular package on a public registry in hopes that developers will accidentally download the malicious package instead of the legitimate library.


In this case, the crate in question is "rustdecimal," a typosquat of the real "[rust\_decimal](https://crates.io/crates/rust_decimal)" package that's been downloaded over 3.5 million times to date. The package was [flagged](https://github.com/paupino/rust-decimal/issues/514) earlier this month on May 3 by Askar Safin, a Moscow-based developer.


According to an [advisory](https://blog.rust-lang.org/2022/05/10/malicious-crate-rustdecimal.html) published by the Rust maintainers, the crate is said to have been first pushed on March 25, 2022, attracting fewer than 500 downloads before it was permanently removed from the repository.


Like prior typosquatting attacks of this kind, the misspelled library replicates the entire functionality of the original library while also introducing a malicious function that's designed to retrieve a Golang binary hosted on a remote URL.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhcx0mm0NLygyjEBxv7CXbP1WpQySBOUw6TmlU6CWa5cQEbouaYL0BiaB1N68AfWiX4RrFlhv2iP7ZuR3QEFyE_Tok_ZX96HH__P1sSmZAaspK6wsyCn5AZ1qgwlIwIm0JfbQ1npA-pPHY2N8uupoK58lUrvJWgVfBJpw8E2VdrHNEYpDacBMUDfUBV/s728-e100/creates.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhcx0mm0NLygyjEBxv7CXbP1WpQySBOUw6TmlU6CWa5cQEbouaYL0BiaB1N68AfWiX4RrFlhv2iP7ZuR3QEFyE_Tok_ZX96HH__P1sSmZAaspK6wsyCn5AZ1qgwlIwIm0JfbQ1npA-pPHY2N8uupoK58lUrvJWgVfBJpw8E2VdrHNEYpDacBMUDfUBV/s728-e100/creates.jpg)
Specifically, the new function checks if the "[GITLAB\_CI](https://docs.gitlab.com/ee/ci/variables/index.html)" environment variable is set, suggesting a "singular interest in GitLab continuous integration ([CI](https://en.wikipedia.org/wiki/CI/CD)) pipelines," SentinelOne noted.


The payload, which is equipped to capture screenshots, log keystrokes, and download arbitrary files, is capable of running on both Linux and macOS, but not Windows systems. The ultimate goals of the campaign are unknown as yet.


While typosquatting attacks have been previously documented against NPM (JavaScript), PyPi (Python), and RubyGems (Ruby), the development marks an uncommon instance where such an incident has been discovered in the Rust ecosystem.


"Software supply-chain attacks have gone from a rare occurrence to a highly desirable approach for attackers to 'fish with dynamite' in an attempt to infect entire user populations at once," SentinelOne researchers said.


"In the case of CrateDepression, the targeting interest in cloud software build environments suggests that the attackers could attempt to leverage these infections for larger scale supply-chain attacks."


  





## Tags:


### Autogenerated tags:
typosquatting sentinelone
