# Experts disclose details of Apache Cassandra DB RCE
## Researchers disclose a now-patched remote code execution (RCE) vulnerability in the Apache Cassandra database software. JFrog researchers publicly disclosed details of a now-patched high-severity security vulnerability (CVE-2021-44521) in Apache Cassandra database software that could be exploited by remote attackers to achieve code execution on affected installations. Apache Cassandra is an open-source NoSQL distributed database used […]
## Information:

+ Link: https://securityaffairs.co/wordpress/128079/breaking-news/apache-cassandra-rce.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 16 February 2022, 15:08
+ Date scraped: 16 February 2022, 16:01

## Article:
![Main article image](https://i0.wp.com/securityaffairs.co/wordpress/wp-content/uploads/2014/05/russia-and-ukraine.jpg?resize=300%2C300&ssl=1)


JFrog researchers publicly disclosed details of a now-patched high-severity security vulnerability ([CVE-2021-44521](https://nvd.nist.gov/vuln/detail/CVE-2021-44521)) in Apache Cassandra database software that could be exploited by remote attackers to achieve code execution on affected installations.


Apache Cassandra is an open-source NoSQL distributed database used by thousands of companies.


*“JFrog’s Security Research team recently disclosed an RCE (remote code execution) issue in [Apache Cassandra](https://cassandra.apache.org/), which has been assigned to [CVE-2021-44521](https://nvd.nist.gov/vuln/detail/CVE-2021-44521) (CVSS 8.4).” reads the [analsyis](https://jfrog.com/blog/cve-2021-44521-exploiting-apache-cassandra-user-defined-functions-for-remote-code-execution/) published by JFrog. “This Apache security vulnerability is easy to exploit and has the potential to wreak havoc on systems, but luckily only manifests in non-default configurations of Cassandra.”*


Cassandra offers the functionality of creating user-defined-functions (UDFs) that allow to perform custom processing of data in the database.


Admins can use Java and JavaScript to write UDFs. In JavaScript it leverages the [Nashorn](https://docs.oracle.com/javase/10/nashorn/introduction.htm#JSNUG136) engine in the Java Runtime Environment (JRE) which is not guaranteed to be secure when accepting untrusted code


JFrog researchers that discovered that when the configuration for user-defined functions ([UDFs](https://cassandra.apache.org/doc/latest/cassandra/cql/functions.html#user-defined-scalar-functions)) are enabled, threat actors could leverage the Nashorn engine to escape the sandbox and achieve remote code execution.


*“For example, running the following Nashorn JavaScript code allows execution of an arbitrary shell command –*



```
java.lang.Runtime.getRuntime().exec("touch hacked")
```

*Cassandra’s development team decided to implement a custom sandbox around the UDF execution which uses two mechanisms to restrict the UDF code” states the report.*“


Experts noticed that the exploitation is possible when the cassandra.yaml configuration file contains the following definitions:


* enable\_user\_defined\_functions: true
* enable\_scripted\_user\_defined\_functions: true
* enable\_user\_defined\_functions\_threads: false


*“When the option is set to false, all invoked UDF functions run in the Cassandra daemon thread, which has a security manager with some permissions. We will show how to abuse these permissions to achieve sandbox escape and RCE.” continues the analysis.*


Experts shared a PoC to create a new file named “hacked” on the Cassandra server


Apache released versions [3.0.26](https://github.com/apache/cassandra/releases/tag/cassandra-3.0.26), [3.11.12](https://github.com/apache/cassandra/releases/tag/cassandra-3.11.12), and [4.0.2](https://github.com/apache/cassandra/releases/tag/cassandra-4.0.2) to address the vulnerability, it adds a new flag “allow\_extra\_insecure\_udfs” that’s set to false by default, it prevents turning off the security manager and blocks access to java.lang.System..


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs)




|  |  |


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, RCE)**



 
  


---


  




## Tags:
***CVE's***: CVE-2021-44521

### Autogenerated tags:
jfrog udfs javascript nashorn udf
