# Google announces V8 Sandbox to protect Chrome users
## Google announced support for a V8 Sandbox in the Chrome web browser to protect users from exploits triggering memory corruption issues.
## Information:

+ Link: https://securityaffairs.com/161622/security/google-v8-sandbox.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 09 April 2024, 09:30
+ Date scraped: 09 April 2024, 11:08

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2024/04/image-9.png)



Google has announced support for what’s called a V8 Sandbox in the Chrome web browser. The company included the [V8 Sandbox](https://g.co/chrome/vrp/#v8-sandbox-bypass-rewards) in Chrome’s Vulnerability Reward Program (VRP). Chrome 123 is a sort of “beta” release for the sandbox designed to mitigate memory corruption issues in the Javascript engine. 


The V8 Sandbox is designed to prevent memory corruption issues that would impact other areas of memory in the process.



Almost every Chrome exploits [observed](https://docs.google.com/spreadsheets/d/1lkNJ0uQwbeC1ZTRrxdtuPLCIl7mlUreoKfSIgajnSyY/edit?usp=sharing) in the wild between 2021 and 2023 triggered a memory corruption issue in a Chrome renderer process that was exploited for remote code execution (RCE). The majority of these issues (60%) impacted the V8 Javascript engine. 


*“V8 vulnerabilities are rarely “classic” memory corruption bugs (use-after-frees, out-of-bounds accesses, etc.) but instead subtle logic issues which can in turn be exploited to corrupt memory. As such, existing memory safety solutions are, for the most part, not applicable to V8.” reads the [**announcement**](https://v8.dev/blog/sandbox). “In particular, neither [switching to a memory safe language](https://www.cisa.gov/resources-tools/resources/case-memory-safe-roadmaps), such as Rust, nor using current or future hardware memory safety features, such as [memory tagging](https://newsroom.arm.com/memory-safety-arm-memory-tagging-extension), can help with the security challenges faced by V8 today.”*


The researchers highlighted that a common thread among nearly all V8 vulnerabilities is that the eventual memory corruption occurs within the V8 heap. This is primarily because the compiler and runtime predominantly deal with V8 HeapObject instances.


To mitigate such vulnerabilities the researchers devised a technique to isolate V8’s (heap) memory to prevent memory corruption from spreading to other parts of the process’ memory.


*“The sandbox limits the impact of typical V8 vulnerabilities by restricting the code executed by V8 to a subset of the process’ virtual address space (“the sandbox”), thereby isolating it from the rest of the process. This works purely in software (with options for hardware support, see the respective design document linked below) by effectively converting raw pointers either into offsets from the base of the sandbox or into indices into out-of-sandbox pointer tables. In principle, these mechanisms are very similar to the userland/kernel separation used by modern operating systems (e.g. the unix file descriptor table).” [states Google](https://source.chromium.org/chromium/chromium/src/+/main:v8/src/sandbox/README.md). “The sandbox assumes that an attacker can arbitrarily and concurrently modify any memory inside the sandbox address space as this primitive can be constructed from typical V8 vulnerabilities. Further, it is assumed that an attacker will be able to read memory outside of the sandbox, for example through hardware side channels. The sandbox then aims to protect the rest of the process from such an attacker. As such, any corruption of memory outside of the sandbox address space is considered a sandbox violation.”*


[Software-based sandbox](https://docs.google.com/document/d/1FM4fQmIhEqPG8uGp5o9A-mnPB5BOeScZYpkHjo0KKA8/edit?usp=sharing) replaces data types that can access out-of-sandbox memory with “sandbox-compatible” alternatives. 


In the software-based sandbox, only the V8 heap is enclosed within the sandbox. As a result, the overall structure is similar to the [sandboxing model](https://webassembly.org/docs/security/) employed by WebAssembly.


[![V8 Sandbox Chrome](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/04/image-9.png?resize=816%2C677&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/04/image-9.png?ssl=1)


![](blob:https://securityaffairs.com/e9912d26-ad37-4ef1-afe6-6efe1f43847b)




The researchers state that the majority of the overhead generated by the sandbox primarily arises from the pointer table indirection for external objects. A minor overhead is related to the use of offsets instead of raw pointers, primarily involving a shift+add operation, anyway this is quite inexpensive. The sandbox’s overhead is approximately 1% or less on standard workloads, as determined by measurements using the Speedometer and JetStream benchmark suites. Consequently, the V8 Sandbox can be activated by default on compatible platforms.


*“The V8 Sandbox must be enabled/disabled at build time using the `v8_enable_sandbox` build flag. It is (for technical reasons) not possible to enable/disable the sandbox at runtime. The V8 Sandbox requires a 64-bit system as it needs to reserve a large amount of virtual address space, currently one terabyte.” concludes the announcement.*


*“The V8 Sandbox has already been enabled by default on 64-bit (specifically x64 and arm64) versions of Chrome on Android, ChromeOS, Linux, macOS, and Windows for roughly the last two years.”*


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking,** **V8 Sandbox)**





---




---





## Tags:


### Autogenerated tags:
v8
