# Magnet Goblin group used a new Linux variant of NerbianRAT malware - Security Affairs
## The financially motivated hacking group Magnet Goblin uses various 1-day flaws to deploy custom malware on Windows and Linux systems.
## Information:

+ Link: https://securityaffairs.com/160274/cyber-crime/magnet-goblin-nerbianrat-attacks.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 11 March 2024, 10:45
+ Date scraped: 11 March 2024, 23:18

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2024/03/image-13.png)


A financially motivated threat actor named Magnet Goblin made the headlines for rapidly adopting and exploiting 1-day vulnerabilities, CheckPoint warned. The group focuses on internet-facing services, in at least one instance the group exploited the vulnerability [CVE-2024-21887](https://securityaffairs.com/158456/security/cisa-order-fix-ivanti-vpn.html) in Ivanti Connect Secure VPN. The researchers noticed that the exploit became part of the group’s toolkit within just one day after a proof of concept (POC) for it was published.


The researchers observed that the threat actor carried out multiple campaigns targeting Ivanti, Magento, Qlink Sense and possibly Apache ActiveMQ.



The attackers demonstrated the capability to quickly use 1-day vulnerabilities. These include:


* **Magento** – [CVE-2022-24086](https://securityaffairs.com/136112/hacking/magento-2-cve-2022-24086.html)
* **Qlik Sense** – CVE-2023-41265, [CVE-2023-41266](https://securityaffairs.com/155615/security/cisa-qlik-sense-flaws-known-exploited-vulnerabilities-catalog.html), and CVE-2023-48365
* **Ivanti Connect Secure** – [CVE-2023-46805](https://securityaffairs.com/158889/security/ivanti-warns-auth-bypass-flaw.html) and [CVE-2024-21887](https://securityaffairs.com/157306/hacking/ivanti-connect-secure-policy-secure-0days.html), [CVE-2024-21888](https://securityaffairs.com/158403/hacking/ivanti-actively-exploited-zero-day-cve-2024-21893.html) and [CVE-2024-21893](https://securityaffairs.com/158403/hacking/ivanti-actively-exploited-zero-day-cve-2024-21893.html).


In the incident involving the Ivanti Connect Secure VPN exploit, threat actors were spotted dropping a previously undetected Linux variant of a malware dubbed [NerbianRAT](https://www.proofpoint.com/us/blog/threat-insight/nerbian-rat-using-covid-19-themes-features-sophisticated-evasion-techniques), along with a JavaScript credential stealer known WARPWIRE. 


NerbianRAT for Windows was first spotted in 2022, however the Linux variant employed by Magnet Goblin has been in circulation since May 2022.


[![Magnet Goblin](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/03/image-13.png?resize=1024%2C614&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/03/image-13.png?ssl=1)


*“While tracking the recent waves of Ivanti exploitation, we identified a number of activities leading to the download and deployment of an ELF file which turned out to be a Linux version of NerbianRAT. This cluster of activity, also described in a Darktrace [report](https://darktrace.com/blog/the-unknown-unknowns-post-exploitation-activities-of-ivanti-cs-ps-appliances), was characterized by the download of a variety of payloads from an attacker-controlled infrastructure.” reads the [report](https://research.checkpoint.com/2024/magnet-goblin-targets-publicly-facing-servers-using-1-day-vulnerabilities/) published CheckPoint. “Among the downloaded payloads are a variant of the WARPWIRE JavaScript credential stealer, a NerbianRAT Linux variant, and Ligolo, an open-source tunneling tool written in GO.”*


Upon executing the Linux NerbianRAT variant, the malware checks for duplicate processes achieved through the allocation of shared memory segments. If successful, it initiates a self-forking mechanism, constituting the sole anti-debugging/anti-analysis measure incorporated into the malware. Once the check is completed, NerbianRAT starts the main initialization process.


Below are the phases of the initiation process:


1. Gathers fundamental information, such as the current time, username, and machine name.
2. Generates a unique bot ID by combining the value of the file /etc/machine-id and the current process ID.
3. Assigns a hardcoded IP address (172.86.66.165) to two global variables, designating them as the primary and secondary hosts.
4. Decrypts the global working directory variable and designates it as %TEMP%.
5. Searches for the file rgs\_c.txt, reads its contents, and attempts to interpret them as the following arguments: -pP port -h host.
6. Loads a public RSA key, subsequently utilized to encrypt network communication


Unlike the Windows variant, the Linux version of NerbianRAT uses raw TCP sockets for communication, exchanging data blobs represented by structs using a customized protocol. The malware uses AES encryption for C2 communication, however, depending on the transmitted data, RSA may also be utilized.


Below are the actions supported by the malware:




| **Action ID** | Action description |
| **1** | Continue requesting more actions. |
| **4** | Run a Linux command in a separate thread. |
| **5** | Send the last command result and clean up the result file. \*\* If a command is running it is stopped. |
| **6** | Run a Linux command immediately. |
| **7** | Do nothing / Idle command. |
| **8** | Change the connection interval global variable. |
| **9** | Update the start and end worktimes, then save the config file. |
| **14** | Send back the idle status timings string / the configuration / results of the last run Linux command. |
| **15** | Set a config variable, based on the name of the field and a value. |
| **16** | Update the gl\_command\_buffer global variable, used when executing commands from the C2. |




The researchers also observed a simplified version of the NerbianRAT, called MiniNerbian, which supports the following actions:


* Execute C2’s command and return results
* Update activity schedule (full day or specific hours)
* Update configuration


Unlike NerbianRAT, MiniNerbian uses HTTP protocol for C2 communication.


[![NerbianRAT](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/03/image-14.png?resize=1007%2C320&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/03/image-14.png?ssl=1)


“Magnet Goblin, whose campaigns appear to be financially motivated, has been quick to adopt 1-day vulnerabilities to deliver their custom Linux malware, NerbianRAT and MiniNerbian. Those tools have operated under the radar as they mostly reside on edge-devices.” concludes the report. “This is part of an ongoing trend for threat actors to target areas which until now have been left unprotected.”


**Follow me on Twitter: [@securityaffairs](https://twitter.com/securityaffairs) and [Facebook](https://www.facebook.com/sec.affairs) and [Mastodon](https://infosec.exchange/@securityaffairs)**


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, Magnet Goblin)**




---




---





## Tags:
***CVE's***: CVE-2024-21888 CVE-2023-41266 CVE-2024-21887 CVE-2023-41265 CVE-2024-21893 CVE-2023-48365 CVE-2023-46805 CVE-2022-24086
***ipv4-adresses***: 172.86.66.165

### Autogenerated tags:
linux nerbianrat malware ivanti c2 1-day mininerbian
