# A Data Exfiltration Attack Scenario: The Porsche Experience
## Whoa! Porsche's API server allows requests from origins other than porsche.com! Find out how this could be exploited and what it means for businesses.
## Information:

+ Link: https://thehackernews.com/2023/07/a-data-exfiltration-attack-scenario.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 28 July 2023, 17:18
+ Date scraped: 28 July 2023, 12:01

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgre0yWsH3iTu4DUeFgN9DY_0vFKxqpTUYus8WkNPM6TWySxaYMeUTUAVcYajZKhd8nWYfjD8R42rN5bB3Ft4nZdaFJAZsTwAaPVCSK6RWDKv8FxRG3GjnoDyhIjfCxHg7n37N8d7pcxIwFl8uQNzDceRsGi7F4SaVLSPr7dlfch3OyurGx_ooRY2kwshU/s728-e365/check.jpg)


As part of [**Checkmarx's mission**](https://checkmarx.com/globalpulsereport/?utm_source=TheHackerNews&utm_medium=cpc&utm_search_query=global-pulse-report&utm_campaign=X-AD-20230424-ALL_LEVEL-THN-ALL-PER-DISPLAY-LP) to help organizations develop and deploy secure software, the Security Research team started looking at the security posture of major car manufacturers. Porsche has a well-established Vulnerability Reporting Policy (Disclosure Policy)[1], it was considered in scope for our research, so we decided to start there, and see what we could find.


What we found is an attack scenario that results from chaining security issues found on different Porsche's assets, a website and a GraphQL API, that could lead to data exfiltration. Data exfiltration is an attack technique that can impact businesses and organizations, regardless of size. When malicious users breach a company's or organization's systems and exfiltrate data, it can be a jarring and business-critical moment.


Porsche has a diverse online presence - deploying several microsites, websites, and web applications. The Porsche Experience [2] is one website that allows registered users to manage a virtual garage, book experiences (such as track days), as well as manage bookings and invoices. From a technical perspective this website is a single-page application (SPA) backed by a GraphQL API (https://experience.porsche.com/graphql) used to fetch data and perform operations such as user authentication, user profile updates, book events, etc.


While initially exploring the website, the team noticed some interesting API requests. More specifically the jwtToken cookie and the Appauthorization HTTP request header both had the same value.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEif5JQxHVJ9eTqPqnPWCSKlfVVwQTWaq5xho62IY8ctqYpy_IV8JP0aiWyxRouNeKN3SuKcsVqrtkRGigVnMw9LLvqOYKXeQ0Yp9Pbpp_4X7hxYEhd1Tal63o6mcWYExPxbLPCdMD8jUDSCYjI5SeaJo6YJzxSxEIAtP2oLAZKI7ZWl7dv988OWH-FLUcc/s728-e365/image6.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEif5JQxHVJ9eTqPqnPWCSKlfVVwQTWaq5xho62IY8ctqYpy_IV8JP0aiWyxRouNeKN3SuKcsVqrtkRGigVnMw9LLvqOYKXeQ0Yp9Pbpp_4X7hxYEhd1Tal63o6mcWYExPxbLPCdMD8jUDSCYjI5SeaJo6YJzxSxEIAtP2oLAZKI7ZWl7dv988OWH-FLUcc/s728-e365/image6.png)
The image above shows the original API request issued by the website front-end to retrieve the user profile after a successful login attempt. On the left (Request) you can see the duplicate value.


This was enough to produce a hypothetical Cross-site Request Forgery (CSRF) [3] attack scenario, leading us to wonder whether the API would look for the authentication token in the jwtToken cookie if the custom HTTP request header Appauthorization was missing.


Including API auth tokens in a request header, rather than Cookie, are a game changer for Cross-Site Request Forgery (CSRF). Web browsers, unlike cookies, do not include such headers automatically, which must be done by some front-end custom logic (JavaScript).


To answer our question, we replayed the original request without including the Appauthorization request header. When we received the same response back from the API server, we confirmed our theory: the API retrieves the auth token from cookies when the custom request header is not present.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEh9PN55J73Tu8nedqP1yLD1-TjqsNaqVaWxoVosuwek3A49-vkKwHL1JXkrGjWDqC3ybU9BR91Y7DGe1Sp_5UZxjDr_h_EdMfRXBfp3GEzKoa6L8uFg-owXWrknhaX51iGKV7KFH-z6OXsiIDz0WRbJfBOftcFPwVZ52hpWvo4Wy29YooBfH0WYF5jQp5s/s728-e365/image5.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEh9PN55J73Tu8nedqP1yLD1-TjqsNaqVaWxoVosuwek3A49-vkKwHL1JXkrGjWDqC3ybU9BR91Y7DGe1Sp_5UZxjDr_h_EdMfRXBfp3GEzKoa6L8uFg-owXWrknhaX51iGKV7KFH-z6OXsiIDz0WRbJfBOftcFPwVZ52hpWvo4Wy29YooBfH0WYF5jQp5s/s728-e365/image5.png)
We had another question in mind that also needed to be answered: would the API server allow requests from origins other than porsche.com?


The answer to this question was also a resounding "yes."


As you can see in the image above, the request was made from a different website, which is reflected in the Access-Control-Allow-Origin [4] response header, indicating that the response can be shared with the requesting code from the given origin. Moreover, the API server also tells browsers to expose the response to the front-end JavaScript code when the request's credentials mode is include [5].


Typically, to be able to perpetrate a CSRF attack from an attacker's-controlled website the victims' web browsers must automatically include the jwtToken cookie in the API requests. That was not the case for Porsche Experience: the jwtToken cookie SameSite attribute was set to Lax.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEglzxwZ832TB34ugu3T2ZpGu2XuKXUrak8NvgLsbLal6HyW0m2G6rNwxoH_Jwj8ur5hWA4YnDqol9wnZ6UDEl8qaXl87TlKBgfMZ39feFeJy9Jz5NNbPGjlz_meoIHGsQvfKbPKmNAB-_KezI5DyUCO55sxGEHWgxKBtIfxzDYip5d_koNxU2NmiIX8lFw/s728-e365/image9.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEglzxwZ832TB34ugu3T2ZpGu2XuKXUrak8NvgLsbLal6HyW0m2G6rNwxoH_Jwj8ur5hWA4YnDqol9wnZ6UDEl8qaXl87TlKBgfMZ39feFeJy9Jz5NNbPGjlz_meoIHGsQvfKbPKmNAB-_KezI5DyUCO55sxGEHWgxKBtIfxzDYip5d_koNxU2NmiIX8lFw/s728-e365/image9.png)
The SameSite attribute [6] controls whether a cookie should be sent with cross-site requests providing some protection against CSRF attacks. Lax means that the cookie is not sent on cross-site requests[7], and it is the default value when not specified at the time the cookie is set. We would not be able to make request to GraphQL API from a website controlled by us, but the definition of "Site" and "Same Site" [8] still leaves us an opportunity.


Any website served from a subdomain of porsche.com using HTTPS is considered "Same Site", and the jwtToken is automatically included by web browsers in requests to the API. Then, all we need to exfiltrate data from the API is to find a way to lead a Porsche website to issue API requests to our target API, sending the response to a server controlled by us. We should not expect to find such a feature on a Porsche website, but a Cross-Site Scripting (XSS) vulnerability [9] would allow us to do it.


The initial reconnaissance process gave us a comprehensive list of Porsche websites which we considered in our research. campaigns.porsche.com was a vulnerable website and the most credible to be included in a "marketing campaign" phishing email.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjuYqQGjab_2-Ntz_D371Z77e8pgmwpUw4BvbE8qjo6qcqt67qKPeW81DoG_ZNe1nW2wQcOcBWHaR6jBkMe9Y7z-FEE9q2tatVsm1aIyB79H6KveK00nDsksgjFc5iN-EUVSyaU8wHneGdZJ-iAZEtbqGaY39EHMLKI-ONcxowwj7sWNwL2Cm2WFwBZDrA/s728-e365/image8.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjuYqQGjab_2-Ntz_D371Z77e8pgmwpUw4BvbE8qjo6qcqt67qKPeW81DoG_ZNe1nW2wQcOcBWHaR6jBkMe9Y7z-FEE9q2tatVsm1aIyB79H6KveK00nDsksgjFc5iN-EUVSyaU8wHneGdZJ-iAZEtbqGaY39EHMLKI-ONcxowwj7sWNwL2Cm2WFwBZDrA/s728-e365/image8.png)
The /charging/WebAjaxGet endpoint of the vulnerable website (campaigns.porsche.com) did not properly sanitize nor encode query string parameter values before including them in the HTML server response. Bad actors could have exploited this issue to inject arbitrary code into the server response, which would end up being executed by the web browser into the victims' session context. Below is the special crafted URL that triggered the alert dialog box in the image above:


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiAjGnN6s6Dj6xOt5_oqm_EBsUE-TYovF934egA4mPB4ur4UwQaKGtEJR4vfvEjrYf8ZSQpMAMd2aITXdJiJWB5bmbHS8h2JbXPHWVWyYlWaadrHrUF3a1eSZ4fcwA3sfVINuDRymndiJv9CFhpQlf1E3hp4L93f_BOGIPdqpIx_N4khkNU040cmeJ9W30/s728-e365/image2.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiAjGnN6s6Dj6xOt5_oqm_EBsUE-TYovF934egA4mPB4ur4UwQaKGtEJR4vfvEjrYf8ZSQpMAMd2aITXdJiJWB5bmbHS8h2JbXPHWVWyYlWaadrHrUF3a1eSZ4fcwA3sfVINuDRymndiJv9CFhpQlf1E3hp4L93f_BOGIPdqpIx_N4khkNU040cmeJ9W30/s728-e365/image2.png)
To exfiltrate data from the API to a remote server, controlled by us, we needed a more complex JavaScript logic. We ended up exploiting the Reflected XSS vulnerability to load a JavaScript script from our remote server. This is how the payload looks like:


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjQUSDTUNJ9bQBqPG_4ufnfqb6XUjSdGG9FVBmxNZGNu4RUI-lSGy_Lzdvx4pDI3EcTubETnUuRFQXDwTXB5SjG3WSrqDBBaDlr2yVBib9U2sfeKlcz50mxAPeDATAlzlJzqjjqNmGA5BXG0NGHJBwE4BsFdHaGpjpAHjbzAwkkDdDnl19n-Y8lY6U9hHc/s728-e365/image1.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjQUSDTUNJ9bQBqPG_4ufnfqb6XUjSdGG9FVBmxNZGNu4RUI-lSGy_Lzdvx4pDI3EcTubETnUuRFQXDwTXB5SjG3WSrqDBBaDlr2yVBib9U2sfeKlcz50mxAPeDATAlzlJzqjjqNmGA5BXG0NGHJBwE4BsFdHaGpjpAHjbzAwkkDdDnl19n-Y8lY6U9hHc/s728-e365/image1.png)
The snippet simply creates a script element, setting the src attribute with the address where our malicious script should be fetched from. When appending it to the Document Object Model (DOM) the script is then downloaded and executed. To avoid encoding issues, the JavaScript payload was encoded base64, and appended to the URL as an argument of the atob JavaScript function, whose output is passed to the eval function. This is how the final crafted URL looks like:


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgt0ecvV8yGPYtqE3sfpZpHH3jx8F9VZuEeqDbGzdKdYZgXByKByp_yr3ZhUasG2JM2DgyeOPpE04rN6NoCwmld-lFny0WUlpIzE_alMJOkNCB0vzQu_UVs7ZAe0CG5vHWBXcZOl-NBngcNw0EUbSD_xADf1AkTFj3s-ly-VuOFsK-z3xAsUrvheKsOYIY/s728-e365/image3.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgt0ecvV8yGPYtqE3sfpZpHH3jx8F9VZuEeqDbGzdKdYZgXByKByp_yr3ZhUasG2JM2DgyeOPpE04rN6NoCwmld-lFny0WUlpIzE_alMJOkNCB0vzQu_UVs7ZAe0CG5vHWBXcZOl-NBngcNw0EUbSD_xADf1AkTFj3s-ly-VuOFsK-z3xAsUrvheKsOYIY/s728-e365/image3.png)
The next step was to write the malicious exfiltrate.js script, downloaded and executed by our XSS payload. For victims, with an active session on experience.porsche.com, the jwtToken auth cookie is automatically included in requests to the API. All we need is to trigger the request with the appropriate GraphQL query and send the response to our remote server. To make the attack a bit sturdier, after that we will redirect the browser to the Porsche Experience website.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEj1YA0suPvsy3XimWOnNT-1Y6DuYT_S801qm-lm0ppbHkRaomQZBRn2l14bt5WXd1CcU_PB7j8I00SBQWANVN35aTnCSE4GHkmMO2MRJbmP_FMRfbV_3ATDdRFQNwoeRnB8hniveAorgapLPUbXN8S-aZYGPvf5OdStKH5jJWWCYTKd0zgocxjcLhwN5eQ/s728-e365/image4.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEj1YA0suPvsy3XimWOnNT-1Y6DuYT_S801qm-lm0ppbHkRaomQZBRn2l14bt5WXd1CcU_PB7j8I00SBQWANVN35aTnCSE4GHkmMO2MRJbmP_FMRfbV_3ATDdRFQNwoeRnB8hniveAorgapLPUbXN8S-aZYGPvf5OdStKH5jJWWCYTKd0zgocxjcLhwN5eQ/s728-e365/image4.png)
With everything in place, and working properly, malicious actors would need to deliver the final malicious URL to victims, enticing them to click it. Email phishing is certainly the most common way attackers do it. The image below illustrates such a phishing email: instead of trying to hide the URL, attacker may have taken advantage of the fact that it starts with HTTPS, and it is an actual porsche.com website.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgH9Rf_ngPAwUBws6bJQlwEVQztfWdBccaKiP_u-LAggtqUVoW6ZoanrIZ1KzXavTQZkGlHv5jISCiz1v2bG40O5Hp7zSuLEjYdBZdQy38yL4uMva7klKDxiyrou3iosYTQo195AWVvuWlPJmB-20GCdro-5bK9zMm7Ulyw5tDCpzDdzav4A6dUP4xQhZk/s728-e365/image7.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgH9Rf_ngPAwUBws6bJQlwEVQztfWdBccaKiP_u-LAggtqUVoW6ZoanrIZ1KzXavTQZkGlHv5jISCiz1v2bG40O5Hp7zSuLEjYdBZdQy38yL4uMva7klKDxiyrou3iosYTQo195AWVvuWlPJmB-20GCdro-5bK9zMm7Ulyw5tDCpzDdzav4A6dUP4xQhZk/s728-e365/image7.png)
This attack scenario is not theoretical, and you can watch the proof-of-concept video provided to Porsche on YouTube [10].


Although this proof-of-concept focuses on profile data exfiltration the loaded JavaScript script could include other logic to retrieve additional data from the GraphQL API (e.g., invoices) or perform actions on victims' behalf (e.g., booking or cancel events).


Some quick security tips:


 To prevent XSS [11] always encode unsafe data, according to the context to which it will be written to. On the APIs side, always establish a proper Cross-Origin Resource Sharing (CORS) policy [12] that restricts what hosts are allowed to interact with it. Also properly set cookies' options, and whenever possible, avoid using cookies to exchange auth tokens between clients and the API server.


It was a pleasure to collaborate with Porsche who took ownership and were professional throughout the disclosure and remediation process. For this reason, and a great researcher experience, we're granting Porsche the Checkmarx Seal of Approval.


And, as always, our security research team will continue to focus on ways to [**improve application security practices**](https://info.checkmarx.com/a-platform-approach-to-shift-everywhere-in-devops?utm_source=TheHackeNews&utm_medium=cpc&utm_campaign=X-AD-20230424-ALL_LEVEL-THN-ALL-PER-DISPLAY-LP&utm_search_query=shift-everywhere-whitepaper) everywhere.



[1]: <https://www.porsche.com/international/product-security/>


[2]: [https://experience.porsche.com](https://experience.porsche.com/)


[3]: <https://owasp.org/www-community/attacks/csrf>


[4]: <https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Origin>


[5]: <https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Credentials>


[6]: <https://owasp.org/www-community/SameSite>


[7]: <https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie#lax>


[8]: <https://developer.mozilla.org/en-US/docs/Glossary/Site>


[9]: <https://owasp.org/www-community/attacks/xss/>


[10]: <https://youtu.be/if0Lmw-tJWo>


[11]: <https://cheatsheetseries.owasp.org/cheatsheets/Cross_Site_Scripting_Prevention_Cheat_Sheet.html>


[12]: <https://cheatsheetseries.owasp.org/cheatsheets/Cross-Site_Request_Forgery_Prevention_Cheat_Sheet.html>



  





## Tags:
***urls***: https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Origin https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie#lax https://experience.porsche.com https://experience.porsche.com/graphql https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Credentials https://www.porsche.com/international/product-security/ https://youtu.be/if0Lmw-tJWo https://owasp.org/www-community/SameSite https://cheatsheetseries.owasp.org/cheatsheets/Cross-Site_Request_Forgery_Prevention_Cheat_Sheet.html https://owasp.org/www-community/attacks/xss/ https://developer.mozilla.org/en-US/docs/Glossary/Site https://owasp.org/www-community/attacks/csrf https://cheatsheetseries.owasp.org/cheatsheets/Cross_Site_Scripting_Prevention_Cheat_Sheet.html

### Autogenerated tags:
api website porsche javascript jwttoken graphql cross-site url csrf xss
