# Google Chrome Adds V8 Sandbox - A New Defense Against Browser Attacks
## Google tackles Chrome security with new V8 Sandbox. This aims to stop memory issues from spreading, protecting your browser experience.
## Information:

+ Link: https://thehackernews.com/2024/04/google-chrome-adds-v8-sandbox-new.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 08 April 2024, 19:21
+ Date scraped: 08 April 2024, 14:09

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhREty2sxBa9Q_hah3r8Khy2a8ioqUhfBu1nf0f03VCnXYxFZzhBnCqVnUTHyksGhR12DkjWpgdUG4G-_a4wwA_couISG76WvaElS_iNAbKBPe7QFLDT7uPUbKfts7Q5vABreFHutAJNqfHstuFaEQLyLS34_5X1KmIMQZh1xapOrWX934GEhQIA4KI2Uox/s728-rw-e365/chrome.png)


Google has announced support for what's called a **V8 Sandbox** in the Chrome web browser in an effort to address memory corruption issues.


The sandbox, according to V8 Security technical lead Samuel Groß, [aims](https://v8.dev/blog/sandbox) to prevent "memory corruption in V8 from spreading within the host process."


The search behemoth has [described](https://bughunters.google.com/about/rules/5745167867576320/chrome-vulnerability-reward-program-rules#v8-sandbox-bypass-rewards) V8 Sandbox as a lightweight, in-process sandbox for the JavaScript and WebAssembly engine that's designed to mitigate common V8 vulnerabilities.


The idea is to limit the impact of V8 vulnerabilities by restricting the code executed by V8 to a subset of the process' virtual address space ("the sandbox") and isolating it from the rest of the process.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiLX0O_pua_BNGD7OG05Td7ASGHjT-c6rLVfmEazcitNrUN4aS12_9AAEWdojbHmrg0EkMQCSyD42w-d6egVdsdVtAEaH-Z0w0f-jU1frNCfaTUp5tY4bg1olzAEY_W1iVATonnvuYqpel_Mxe4TJmkCMSqLOo4ol9NEGBRh_a8C0JhApfKqY8f-wf9m978/s728-e365/wing-d.png)](https://thehackernews.uk/automated-remediation-wing)
Shortcomings affecting V8 have accounted for a significant chunk of the zero-day vulnerabilities that Google has [addressed](https://thehackernews.com/2021/12/update-google-chrome-to-patch-new-zero.html) between [2021](https://thehackernews.com/2022/12/google-rolls-out-new-chrome-browser.html) and [2023](https://thehackernews.com/2023/12/urgent-new-chrome-zero-day.html), with as many as 16 security flaws discovered over the time period.


"The sandbox assumes that an attacker can arbitrarily and concurrently modify any memory inside the sandbox address space as this primitive can be constructed from typical V8 vulnerabilities," the Chromium team [said](https://source.chromium.org/chromium/chromium/src/+/main:v8/src/sandbox/README.md).


"Further, it is assumed that an attacker will be able to read memory outside of the sandbox, for example, through hardware side channels. The sandbox then aims to protect the rest of the process from such an attacker. As such, any corruption of memory outside of the sandbox address space is considered a sandbox violation."


Groß emphasized the challenges with tackling V8 vulnerabilities by switching to a memory-safe language like Rust or hardware memory safety approaches, such as memory tagging, given the "subtle logic issues" that can be exploited to corrupt memory, unlike classic memory safety bugs like use-after-frees, out-of-bounds accesses, and others.


[![Chrome V8 Sandbox](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhGv2Sh-vA3wrQOlQIdhjsaeXu9OyOwU49wCmFjXDL-U8muV8m_i3V-AuyYpfujBJ_HkUyWBMBFPkHl6Uz6N8olik1nuWljkCKDUu1rbQ0CV_xCiXK-ez9xMF19RI8bABrXMaCRlt62aRH-SlBnPZ4N82DV5mg2ux2MonMH9LwcZ3ql0yF5AxGQLUDFEvlj/s728-rw-e365/sandbox.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhGv2Sh-vA3wrQOlQIdhjsaeXu9OyOwU49wCmFjXDL-U8muV8m_i3V-AuyYpfujBJ_HkUyWBMBFPkHl6Uz6N8olik1nuWljkCKDUu1rbQ0CV_xCiXK-ez9xMF19RI8bABrXMaCRlt62aRH-SlBnPZ4N82DV5mg2ux2MonMH9LwcZ3ql0yF5AxGQLUDFEvlj/s728-rw-e365/sandbox.png)
"Nearly all vulnerabilities found and exploited in V8 today have one thing in common: the eventual memory corruption necessarily happens inside the V8 heap because the compiler and runtime (almost) exclusively operate on V8 HeapObject instances," Groß said.


Given that these issues cannot be protected by the same techniques used for typical memory-corruption vulnerabilities, the V8 Sandbox is designed to isolate V8's heap memory such that should any memory corruption occur, it cannot escape the security confines to other parts of the process' memory.


This is accomplished by replacing all data types that can access out-of-sandbox memory with "sandbox-compatible" alternatives, thereby effectively preventing an attacker from accessing other memory. The sandbox can be enabled by setting "v8\_enable\_sandbox" to true in the [gn args](https://v8.dev/docs/build-gn).


Benchmark results from Speedometer and JetStream show that the security feature adds an overhead of about 1% on typical workloads, allowing it to be enabled by default starting with Chrome version 123, spanning Android, ChromeOS, Linux, macOS, and Windows.


"The V8 Sandbox requires a 64-bit system as it needs to reserve a large amount of virtual address space, currently one terabyte," Groß said.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj9LS2CMV85AM5f2fKKl2aPAnQ1iZEQKbHh7hRbW3rn3MowE5BXNOrNlHsrMYRMndplTjEmzciLAj6jVsDkRJI2IdSfFXSXuSlMn6gSgmzjKktBgyRTJsC-MayMQq8Z580Hjp8oCv0WoplbNRKlOEzR3RqajPwbLY2JzbQpwEIaW6u2UDkYmcWPO_Mmzq-X/s728-e365/cis-d.png)](https://thehackernews.uk/cis-controls-guide-sme)
"The sandbox is motivated by the fact that current memory safety technologies are largely inapplicable to optimizing JavaScript engines. While these technologies fail to prevent memory corruption in V8 itself, they can in fact protect the V8 Sandbox attack surface. The sandbox is therefore a necessary step towards memory safety."


The development comes as Google highlighted the role by Kernel Address Sanitizer ([KASan](https://source.android.com/docs/security/test/asan)) in detecting memory bugs in native code and help [harden Android firmware security](https://thehackernews.com/2023/12/google-using-clang-sanitizers-to.html), adding it used the compiler-based tool for discovering more than 40 bugs.


"Using KASan enabled builds during testing and/or fuzzing can help catch memory corruption vulnerabilities and stability issues before they land on user devices," Eugene Rodionov and Ivan Lozano from the Android team [said](https://security.googleblog.com/2024/03/address-sanitizer-for-bare-metal.html).


  





## Tags:


### Autogenerated tags:
v8 groß google android
