# How to Conduct Advanced Static Analysis in a Malware Sandbox
## Ever worried about malware in PDFs? ANY.RUN's sandbox can expose hidden threats just by analyzing the file's structure.
## Information:

+ Link: https://thehackernews.com/2024/04/how-to-conduct-advanced-static-analysis.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 18 April 2024, 16:01
+ Date scraped: 18 April 2024, 11:10

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjdLdeFsBp5WcONUpj6fXxAiA0NaKBUWrKpEK2jD90_XgRoUKtGT9pRY4XEqsvCYrO5v6TJL20ohj4jkmJ7Mb_sIcJQuJSvhofPamGdWtcYD9ReTVqaY1mgJ2qkxx0LYQjBoQj0yU2-NJgNwtCEJaVH8P1UCE8TTGLIYeTlUwAf5eRjDc-Mgy5gGN8q53o/s728-rw-e365/anyrun.png)


Sandboxes are synonymous with dynamic malware analysis. They help to execute malicious files in a safe virtual environment and observe their behavior. However, they also offer plenty of value in terms of static analysis. See these five scenarios where a sandbox can prove to be a useful tool in your investigations.


Detecting Threats in PDFs[#](#detecting-threats-in-pdfs)
--------------------------------------------------------


PDF files are frequently exploited by threat actors to deliver payloads. Static analysis in a sandbox makes it possible to expose any threat a malicious PDF contains by extracting its structure.


The presence of JavaScript or Bash scripts can reveal a possible mechanism for downloading and executing malware.


Sandboxes like ANY.RUN also allows users to scrutinize URLs found in PDFs to identify suspicious domains, potential command and control (C2) servers, or other indicators of compromise.


### Example:[#](#example)


![Malware Sandbox](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgyaYabscfu0iyl-sLBKdz6YNnowfvk8TmsPuBmeB8FrQnSdOfWxTcZJ4x9kuqEXVTV3m9gg4BG8zc8z1nT0fcTywaOn-kcsAt7lHxO8xvz5jyjIxZcuitfVaCiiWuTVDAcB_s9xm6JBVJjySYUXUD2eyQbFQzKL4ddmgwiPfiTpNPcQgVIfUEpISZv30c/s1500/1.png)
Interactivity allows our users to manipulate files within a VM as they wish, but static Discovery offers even more opportunities.


As part of [this analysis session](https://app.any.run/tasks/f30dc54f-3b5e-478f-a97e-cf53029ce0b4/?utm_source=thehackernews&utm_medium=article&utm_campaign=staticanalysis&utm_term=tasks1&utm_content=180424), the static module lists several URLs that can be found inside the PDF. To investigate them, we can submit each of these for further sandbox analysis by simply clicking a corresponding button.




See how static and dynamic analysis in the ANY.RUN sandbox can benefit your security team.


[Book a personal demo](https://calendly.com/d/ckfs-7hp-rtv/any-run-demo-meeting-the-hacker-news/) of the service today!




Exposing LNK Abuse[#](#exposing-lnk-abuse)
------------------------------------------


LNK files are shortcuts that direct to an executable file, a document, or a folder. A sandbox can provide a transparent view of the LNK file's properties, such as its target path, icon location, and any embedded commands or scripts.


Viewing commands in LNK files can reveal attempts to launch malicious software or connect to remote servers.


Static analysis in a sandbox is particularly useful in identifying threats that do not spawn a new process. These can be difficult to detect through dynamic analysis alone.


### Example:[#](#example)


![Malware Sandbox](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEja6m7ZjEBpKGHJr-iYZTBBAJy5wn0aklZMfJPqy7xaaSwDGwj0srCgZY_Tuqn0-Sri75psqvBUqWO1oqBpuk6DS8KTkJSwAe9IBbIAMIx6J1MThGsMJQ0pcbP8sFGd3vxEOzBn9LHyS04GP4PuSqOtZkpD9_H_OfFQZhiYUG-b9SMUd7yz81xMXgUUPnQ/s1500/2.png)
Examining the contents of LNK files can help you detect attacks before they begin.


In [this sandbox session](https://app.any.run/tasks/ccdf819e-be33-4ce5-b3b1-c3ec919badd5/?utm_source=thehackernews&utm_medium=article&utm_campaign=staticanalysis&utm_term=tasks2&utm_content=180424), we can discover every detail about the LNK file, including its command line arguments which show that the file is configured to download and execute a payload from a malicious URL.


Investigating Spam and Phishing Emails[#](#investigating-spam-and-phishing-emails)
----------------------------------------------------------------------------------


Email remains one of the most common vectors for malware distribution. A sandbox lets you upload an email file to the service and analyze it safely to spot spam and hidden malicious elements faster and without any risk to your infrastructure.


A sandbox shows an email preview and lists metadata and Indicators of Compromise (IOCs). You can examine the content of the email without opening it and study the metadata that provides information about the email's origin, timestamps, and other relevant details.


[The ANY.RUN sandbox](https://any.run?utm_source=thehackernews&utm_medium=article&utm_campaign=staticanalysis&utm_term=landing&utm_content=180424) also integrates RSPAMD, an open-source module that assigns a phishing score to each analyzed email and displays all of its elements using these features:


* **Header Analysis:** Examines email headers for sender authenticity and anomalies.
* **Reputation Checks:** Identifies known spam/malware sources using DNSBLs and URIBLs.
* **Bayesian Filtering:** Classifies emails based on probabilistic analysis.


In ANY.RUN, you can move beyond static analysis and interact with the email directly like you would on your own computer. This means you can download and open attachments, including password-protected ones, or follow through the entire phishing attack, starting from the initial link.


### Example: [#](#example)


![Malware Sandbox](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjdgkBobl5fXNxUGD65ObuKdj8-T_te7eQLY_nQXhva7zcMbzxyfS8vMfAW3lsBGK5OBlPHMHQ32vIfCjLIaKHRwNRD5X7E_kWxZenuJu65s6y4Veq_UQP4sJQuNHmp-r-Qu1jxdQdJFFsK9IJx-xv46gOZaJ9FFTRdNZ2HmBfoaHBZX2M6L7MYh4pYozU/s1500/3.png)
All content within EMAIL files is extracted and made available through static analysis in the sandbox, allowing users to view details about it even without accessing the VM itself.


In [this analysis session](https://app.any.run/tasks/fd1d4d78-4c6a-4bba-82e6-c599ecb3b5b7/?utm_source=thehackernews&utm_medium=article&utm_campaign=staticanalysis&utm_term=tasks3&utm_content=180424), we can observe a .RAR attachment which accompanies the email. Given that one of the files located inside of this archive is an executable named "Commercial Invoice PDF", we can instantly assume its malicious nature.


To analyze the executable, we can simply click the "Submit to analyze" button and launch a new sandbox session.


Analyzing Suspicious Office Documents[#](#analyzing-suspicious-office-documents)
--------------------------------------------------------------------------------


Microsoft Office documents, such as Word, Excel, and PowerPoint ones, are one of the leading security risks in both corporate and personal settings. Sandbox static analysis can be employed to scrutinize various elements of such documents without opening them. These include:


* **Content:** Sandbox static analysis enables you to examine the document's content for signs of social engineering tactics, phishing attempts, or suspicious links.
* **Macros:** Attackers often exploit Visual Basic for Applications (VBA) code in Office documents to automate malicious tasks. These tasks can range from downloading and executing malware to stealing sensitive data. [ANY.RUN](https://any.run/) shows the entire execution chain of the script, enabling you to study it step by step.
* **Images and QR Codes:** Steganography techniques let attackers conceal code within images. Sandbox static analysis is capable of extracting this hidden data. QR codes embedded within documents may also contain malicious links. A sandbox can decode these and expose the potential threats.
* **Metadata:** Information about the document's creation, modification, author, etc. can help you understand the document's origin.


### Example:[#](#example)


![Malware Sandbox](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEh7s8SjLQERcUgViTlhCL1tEXWvrzrbrQi0woHRiLTCr1_5_tGA0xTa-ZG1UtsKSIa_PLo-lJ6vbIhp8gJxMfVAcP6-qQO626rzBkn0mRSlEuRerJKhJpHWLTZlbqC3g6WlWAlYL36d3ET2ZbLczIDO9n0p4IoLkV-qQegkdg7P2GjrbOCsWa_lxdlEEHk/s728-rw-e365/4.png)
Microsoft Office files come in various formats, and analyzing their internal structure can sometimes be challenging. Static Discovery for Office files allows you to examine macros without needing additional tools.


All embedded files, including images, scripts, and executable files, are also accessible for further analysis. QR codes are detected during static analysis, and users can submit a new task that opens the content encoded in these codes, such as URLs.


In [this session](https://app.any.run/tasks/c8bdc95a-0906-4529-acf5-2db4e7a8aded/?utm_source=thehackernews&utm_medium=article&utm_campaign=staticanalysis&utm_term=tasks4&utm_content=180424), static analysis makes it possible to see that the analyzed .pptx file contains a .zip archive.


Looking Inside Malicious Archives[#](#looking-inside-malicious-archives)
------------------------------------------------------------------------


Archives like ZIP, tar.gz, .bz2, and RAR are frequently used as means to bypass basic detection methods. A sandbox environment provides a safe and isolated space to analyze these files.


For instance, sandboxes can unpack archives to reveal their contents, including executable files, scripts, and other potentially malicious components. These files can then be analyzed using the built-in static module to expose their threats.


### Example:[#](#example)


![Malware Sandbox](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEggrTrtDLlJpgH1kj-7sqgT87ZDlCaZZOyg-L9UVghO6RJrxit7sqyjHS09cklopc2BMtbdEn3zPC2csd3jmHb4YoMk3NHHj49DxM9Zeh7X_ozWR1Reqo_zjqmb6Yxlt5gBnZA-cmLsD7YTUl35nIZH3ttv2_JmOtupZ4YbHKhld0XzRyAIJ1YK8ck6jjQ/s1500/5.png)
In ANY.RUN, users can submit files for new analysis directly from archived files from the static discovery window. This eliminates the need to download or manually unpack them inside a VM.


In this [analysis session](https://app.any.run/tasks/a2c6cf72-caea-435b-8395-8ca0cd9d90c9/?utm_source=thehackernews&utm_medium=article&utm_campaign=staticanalysis&utm_term=tasks5&utm_content=180424), we once again see an archive with files that can be studied one by one to determine whether any additional analysis is required.


Conduct Static and Dynamic Analysis in ANY.RUN[#](#conduct-static-and-dynamic-analysis-in-anyrun)
-------------------------------------------------------------------------------------------------


ANY.RUN is a cloud-based sandbox with advanced static and dynamic analysis capabilities. The service lets you scan suspicious files and links and get the first results on their threat level in under 40 seconds. It gives you a real-time overview of the network traffic, registry activities, and processes occurring during malware execution, highlighting malicious behavior and the tactics, techniques, and procedures (TTPs).


ANY.RUN provides you with complete control over the VM, making it possible to interact with the virtual environment just like on a standard computer. The sandbox generates comprehensive reports that feature key threat information, including indicators of compromise (IOCs).


[Start using ANY.RUN today](https://app.any.run/?utm_source=thehackernews&utm_medium=article&utm_campaign=staticanalysis&utm_term=register&utm_content=180424#register/) for free and enjoy unlimited malware analysis in Windows and Linux VMs.


  





## Tags:


### Autogenerated tags:
any.run malware lnk pdf example:# vm phishing urls metadata
