# New 'ParseThru' Parameter Smuggling Vulnerability Affects Golang-based Applications
## Researchers have discovered a new "New ParseThru" parameter smuggling vulnerability affecting GoLang-based applications.
## Information:

+ Link: https://thehackernews.com/2022/08/new-parsethru-parameter-smuggling.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 02 August 2022, 12:05
+ Date scraped: 02 August 2022, 13:01

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjhUPJ7zWn9N4getd5s32RFCbWi1zd-KJU_ypeTy6hqyLfxm93aUbRZAN27TSSqUXOo0A7mTeTWRHgIrXZNJC6Spk-piz4t7ajdvuKGHN7J9I0bYbGZW0Agqv4QwCy3foukE8ek0Ex9tiw4Y651lyFh2WEbhS37XGc6tY0Gg13HW7jW1-O-FZlgTUo2/s728-e1000/golang.jpg)


Security researchers have discovered a new vulnerability called **ParseThru** affecting Golang-based applications that could be abused to gain unauthorized access to cloud-based applications.


"The newly discovered vulnerability allows a threat actor to bypass validations under certain conditions, as a result of the use of unsafe URL parsing methods built in the language," Israeli cybersecurity firm Oxeye said in a [report](https://www.oxeye.io/blog/golang-parameter-smuggling-attack) shared with The Hacker News.


The issue, at its core, has to do with inconsistencies stemming from changes introduced to Golang's URL parsing logic that's implemented in the "net/url" library.


While versions of the programming language prior to 1.17 treated semicolons as a valid query delimiter (e.g., example.com?a=1;b=2&c=3), this behavior has since been modified to throw an error upon finding a query string containing a semicolon.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiQ71A2FdqKbMr4bZGHK3yFPiQoBq8II9uJrdfUasUZ84tz7O72ZY8cnomMWyW2WJlVELzzYX97YhzBS_eq52r6R8ouus4Aa5xb2LxsY59BpjymMdzOyqMmA2bta_D5BWRLZ8p6Nc6TZa2y-FKeIg_LIN2oW-xH0yPmLjSrGvrNxXvKDdJfC6JoRygA/s728-e100/map.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiQ71A2FdqKbMr4bZGHK3yFPiQoBq8II9uJrdfUasUZ84tz7O72ZY8cnomMWyW2WJlVELzzYX97YhzBS_eq52r6R8ouus4Aa5xb2LxsY59BpjymMdzOyqMmA2bta_D5BWRLZ8p6Nc6TZa2y-FKeIg_LIN2oW-xH0yPmLjSrGvrNxXvKDdJfC6JoRygA/s728-e100/map.jpg)
"The net/url and net/http packages used to accept ";" (semicolon) as a setting separator in URL queries, in addition to "&" (ampersand)," according to the [release notes](https://go.dev/doc/go1.17#semicolons) for version 1.17 released last August.


"Now, settings with non-percent-encoded semicolons are rejected and net/http servers will log a warning to 'Server.ErrorLog' when encountering one in a request URL."


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEixyEesWdt9Kn9GU1HhKN4gt973TzAbj21P2K2MMovbGpXL7yg_7J7SDLgBBt8dHvD1EonOs5J1RdEG5m3HD320xd8I1IfXv3aDYOpTdCoe3-O_uI0hMY6kv10hd6V_Ax9Qtf797vHXcVm1EJ4XvOt_aeRnRWgcKMHuC10-Gzlwwzc7otVktJ4RApjL/s728-e100/code.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEixyEesWdt9Kn9GU1HhKN4gt973TzAbj21P2K2MMovbGpXL7yg_7J7SDLgBBt8dHvD1EonOs5J1RdEG5m3HD320xd8I1IfXv3aDYOpTdCoe3-O_uI0hMY6kv10hd6V_Ax9Qtf797vHXcVm1EJ4XvOt_aeRnRWgcKMHuC10-Gzlwwzc7otVktJ4RApjL/s728-e100/code.jpg)
The problem arises when a Golang-based public API built upon version 1.17 or later communicates with a backend service running an earlier version, leading to a scenario where a malicious actor could smuggle requests incorporating query parameters that would otherwise be rejected.


Put simply, the idea is to send requests containing a semicolon in the query string, which is ignored by the user-facing Golang API but is processed by the internal service. This, in turn, is made possible owing to the fact that [one of the methods](https://pkg.go.dev/net/url#URL.Query) responsible for getting the parsed query string silently discards the returned error.


Oxeye said it identified several instances of ParseThru in open-source projects such as Harbor, Traefik, and Skipper, which made it possible to bypass validations put in place and carry out unauthorized actions. The issues have been addressed following responsible disclosure to the respective vendors.


This is not the first time URL parsing has posed a security issue. Earlier this January, Claroty and Snyk [disclosed](https://thehackernews.com/2022/01/researchers-find-bugs-in-over-dozen.html) as many as eight flaws in third-party libraries written in C, JavaScript, PHP, Python, and Ruby languages that originated as a result of confusion in URL parsing.


  





## Tags:


### Autogenerated tags:
url
