# New BrutePrint Attack Lets Attackers Unlock Smartphones with Fingerprint Brute-Force
## BrutePrint: A new attack technique targeting smartphone fingerprint authentication.
## Information:

+ Link: https://thehackernews.com/2023/05/new-bruteprint-attack-lets-attackers.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 29 May 2023, 20:01
+ Date scraped: 29 May 2023, 15:03

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEijBNG4NMOJTJEZS44gfOa6C-9ERWD_xxZ3YOP4FGMgadv17tftI7USFvh4CA3yBVSWLSm0I2fkslSMQ7LPumsx2ElB6Vo-_JTOphxw_ukdX9-Zxj5jHZaoeX68ORZV1OWT09J_0_uivx_-9TKLE1uZ_-1waziB7IrCyvpKdZkMOmsvkUFY8vK3rsG5/s728-e365/finger.jpg)


Researchers have discovered an inexpensive attack technique that could be leveraged to brute-force fingerprints on smartphones to bypass user authentication and seize control of the devices.


The approach, dubbed **BrutePrint**, bypasses limits put in place to counter failed biometric authentication attempts by weaponizing two zero-day vulnerabilities in the smartphone fingerprint authentication (SFA) framework.


The flaws, Cancel-After-Match-Fail (CAMF) and Match-After-Lock (MAL), leverage logical defects in the authentication framework, which arises due to insufficient protection of fingerprint data on the Serial Peripheral Interface (SPI) of fingerprint sensors.


The result is a "hardware approach to do man-in-the-middle (MitM) attacks for fingerprint image hijacking," researchers Yu Chen and Yiling He [said](https://arxiv.org/abs/2305.10791) in a research paper. "BrutePrint acts as a middleman between fingerprint sensor and [TEE](https://thehackernews.com/2022/08/xiaomi-phones-with-mediatek-chips-found.html) [Trusted Execution Environment]."


The goal, at its core, is to be able to perform an unlimited number of fingerprint image submissions until there is a match. It, however, presupposes that a threat actor is already in possession of the target device in question.


Additionally, it requires the adversary to be in possession of a fingerprint database and a setup comprising a microcontroller board and an auto-clicker that can hijack data sent by a fingerprint sensor to pull off the attack for as low as $15.


The first of the two vulnerabilities that render this attack possible is CAMF, which allows for increasing the fault tolerance capabilities of the system by invalidating the [checksum](https://en.wikipedia.org/wiki/Checksum) of the fingerprint data, thereby giving an attacker unlimited tries.


MAL, on the other hand, exploits a side-channel to infer matches of the fingerprint images on the target devices, even when it enters a lockout mode following too many repeated login attempts.


"Although the lockout mode is further checked in Keyguard to disable unlocking, the authentication result has been made by TEE," the researchers explained.


"As Success authentication result is immediately returned when a matched sample is met, it's possible for side-channel attacks to infer the result from behaviors such as response time and the number of acquired images."


In an experimental setup, BrutePrint was evaluated against 10 different smartphone models from Apple, Huawei, OnePlus, OPPO, Samsung, Xiaomi, and vivo, yielding infinite attempts on Android and [HarmonyOS](https://en.wikipedia.org/wiki/HarmonyOS), and 10 additional attempts on iOS devices. 


The findings come as a group of academics detailed a hybrid side-channel that takes advantage of the "three-way tradeoff between execution speed (i.e., frequency), power consumption, and temperature" in modern system-on-chips (SoCs) and GPUs to conduct "browser-based pixel stealing and history sniffing attacks" against Chrome 108 and Safari 16.2.


The attack, called [Hot Pixels](https://arxiv.org/abs/2305.12784), takes advantage of this behavior to mount website fingerprinting attacks and employ JavaScript code to harvest a user's browsing history.


 UPCOMING WEBINAR Zero Trust + Deception: Learn How to Outsmart Attackers! Discover how Deception can detect advanced threats, stop lateral movement, and enhance your Zero Trust strategy. Join our insightful webinar!

 [Attend for Free](https://thn.news/z-inside-2).ad-button,.ad-label,.ad-label:after{display:inline-block}.ad\_two\_webinar{margin:20px 10px 30px 0;background:#f9fbff;color:#160755;padding:0 5%;border:2px solid #d9deff;border-radius:10px;text-align:left;box-shadow:10px 10px 0 #e2ebff;-webkit-border-top-left-radius:25px;-moz-border-radius-topleft:25px;-webkit-border-bottom-right-radius:25px;-moz-border-radius-bottomright:25px}.ad-label{font-size:13px;margin:20px 0 0;font-weight:600;letter-spacing:.6px;color:#596cec}.ad-label:after{width:50px;height:6px;content:'';border-top:2px solid #d9deff;margin:0 8px}.ad-title{font-size:21px;padding:10px 0 0;font-weight:900;text-align:left;line-height:33px}.ad-description{text-align:left;font-size:15.6px;line-height:26px;margin:5px 0!important;color:#4e6a8d}.ad-button{padding:6px 12px;border-radius:5px;background-color:#4469f5;font-size:15px;color:#fff!important;border:0;line-height:inherit;text-decoration:none!important;cursor:pointer;margin:15px 0 20px;float:left;font-weight:500;letter-spacing:.2px}
This is accomplished by designing a computationally heavy SVG filter to leak pixel colors by measuring the rendering times and stealthily harvest the information with an accuracy as high as 94%.


The issues have been acknowledged by Apple, Google, AMD, Intel, Nvidia, Qualcomm. The researchers also recommend "prohibiting SVG filters from being applied to iframes or hyperlinks" and preventing unprivileged access to sensor readings.


BrutePrint and Hot Pixels also follow [Google's](https://googleprojectzero.blogspot.com/2023/04/technical-report-into-intel-tdx.html) [discovery](https://cloud.google.com/blog/products/identity-security/rsa-google-intel-confidential-computing-more-secure) of [10 security defects](https://community.intel.com/t5/Blogs/Products-and-Solutions/Security/Intel-Google-TDX-Security-Review/post/1471177) in Intel's Trust Domain Extensions ([TDX](https://www.intel.com/content/www/us/en/developer/articles/technical/intel-trust-domain-extensions.html)) that could lead to arbitrary code execution, denial-of-service conditions, and loss of integrity. 


On a related note, Intel CPUs have also been found [susceptible](https://arxiv.org/abs/2304.10877) to a side-channel attack that makes use of variations in execution time caused by changing the [EFLAGS register](https://en.wikipedia.org/wiki/FLAGS_register) during [transient execution](https://thehackernews.com/2022/07/new-retbleed-speculative-execution.html) to decode data without relying on the cache.


  





## Tags:


### Autogenerated tags:
bruteprint side-channel
