# Node.js Users Beware: Manifest Confusion Attack Opens Door to Malware
## Developers, beware! npm packages are vulnerable to manifest confusion. This could serve as a backdoor for malicious code, hiding in your project
## Information:

+ Link: https://thehackernews.com/2023/07/nodejs-users-beware-manifest-confusion.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 05 July 2023, 14:30
+ Date scraped: 05 July 2023, 10:01

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEj7li4QbxABeEwcNT2gHDZfIhiviDu40c7u7wu4n9b6ED5FSoAjIwe6YJK088GzeSxrgqtA70Ly30w45C95dTLsmLl1Pj6rzCJSkuuugL9jqzyL0oht453c0YrVaH_COTFIMXh6Ilv9_0y5C83tBJ2-qRpvinMeIbSsPOmKbUgsocJl6uq2vwbvdxMXgqI/s728-e3650/npm-malware.png)


The npm registry for the Node.js JavaScript runtime environment is susceptible to what's called a **manifest confusion** attack that could potentially allow threat actors to conceal malware in project dependencies or perform arbitrary script execution during installation.


"A npm package's manifest is published independently from its tarball," Darcy Clarke, a former GitHub and npm engineering manager, [said](https://blog.vlt.sh/blog/the-massive-hole-in-the-npm-ecosystem) in a technical write-up published last week. "Manifests are never fully validated against the tarball's contents."


"The ecosystem has broadly assumed the contents of the manifest and tarball are consistent," Clarke added.


The problem, at its core, stems from the fact that the manifest and package metadata are decoupled and that they are never cross-referenced against one another, thereby leading to unexpected behavior and misuse when there is a mismatch.


As a result, a threat actor could exploit this loophole to publish a module with a manifest file (package.json) that contains hidden dependencies as well as run install scripts, which could then pave the way for a supply chain attack and the poisoning of a developer's environment.


"Manifest confusion becomes problematic in development environments without effective DevSecOps workflows and tooling in place, especially when applications blindly trust application manifests rather than the actual (vulnerable or malicious) files contained within open source packages," Sonatype researcher and journalist Ax Sharma [said](https://blog.sonatype.com/npm-manifest-confusion-what-is-it-and-do-you-really-need-to-worry-about-it).


The finding underscores the fact that metadata contained within package manifest files alone cannot be relied upon when downloading a package from the open-source repository, necessitating that users take steps to [scan packages](https://owasp.org/www-community/Source_Code_Analysis_Tools) for any anomalous features and exploits.


[![Manifest Confusion Attack](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEheoKiD4pZavi-OPjy7TDIPAuwONx1aCfvSAWGfsywKKfQCpOYKN2BBbcYOlmDCA_pspO-cRxsJ39HTUzE0EoQc3Dyq_NPybjgMiSOs4LUUg0qVx5lSWI7DacG40Dk0MesHDcCbmlkSDI0ri-k8Brepcuk8DVIua2s4a7_zxJTWAwjsCmIaRKKhn5t22G4/s728-e3650/npm.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEheoKiD4pZavi-OPjy7TDIPAuwONx1aCfvSAWGfsywKKfQCpOYKN2BBbcYOlmDCA_pspO-cRxsJ39HTUzE0EoQc3Dyq_NPybjgMiSOs4LUUg0qVx5lSWI7DacG40Dk0MesHDcCbmlkSDI0ri-k8Brepcuk8DVIua2s4a7_zxJTWAwjsCmIaRKKhn5t22G4/s728-e365/npm.png)
GitHub, per Clarke, is said to be aware of the problem since at least early November 2022, with the Microsoft subsidiary stating it plans to address it internally as of March 2023. The issue, however, remains unresolved to date.


In the absence of an official fix, security researcher Felix Pankratz has made available a [Python script](https://github.com/panki27/npm-manifest-check) that can be used to test for mismatches between the manifests in npm modules.


The development also comes as developer security company Snyk, in partnership with Redhunt Labs, examined 11,900 repositories from the [top 1,000 GitHub organizations](https://github.com/redhuntlabs/Project-Resonance/blob/master/Wave%203%20-%20Dependency%20Confusion/orgs.txt) for insecure dependencies, uncovering 1,229,601 flaws in 15,584 vulnerable dependency files.


UPCOMING WEBINAR[🔐 Privileged Access Management: Learn How to Conquer Key Challenges](https://thn.news/pam-webinar)Discover different approaches to conquer Privileged Account Management (PAM) challenges and level up your privileged access security strategy.

[Learn, Connect, Grow](https://thn.news/pam-webinar)
"[Deserialization of untrusted data](https://cwe.mitre.org/data/definitions/502.html) was the most prevalent vulnerability type with a whopping 130,831 occurrences in Java repositories, making it 40 percent of the total vulnerabilities identified," the study [said](https://snyk.io/blog/snyk-redhunt-labs-scanning-top-1000-orgs-on-github/).


In JavaScript-based projects, [prototype pollution](https://cwe.mitre.org/data/definitions/1321.html) emerged as the leading shortcoming with 343,332 occurrences. Denial-of-service ([DoS](https://attack.mitre.org/techniques/T0814/)) flaws contributed to the most in Python and Ruby projects with 19,652 and 56,331 occurrences, respectively.


"The threat of vulnerable dependencies disrupting the state of security of software supply chains is here to stay," security researchers Umair Nehri and Vandana Verma Sehgal said. "So, developers must be careful with the dependencies they use in their projects and keep them up-to-date to keep them patched from any known vulnerabilities."


  





## Tags:


### Autogenerated tags:
npm tarball github
