# Researchers Disclose Critical RCE Vulnerability Affecting Quarkus Java Framework
## Researchers have disclosed a critical remote code execution (RCE) vulnerability (CVE-2022-4116) affecting the Quarkus Java framework.
## Information:

+ Link: https://thehackernews.com/2022/12/researchers-disclose-critical-rce.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 01 December 2022, 11:44
+ Date scraped: 01 December 2022, 12:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgm_pWTip4dw5H_VmMNdPZIuxyVTTTokUv9wsI7SnFyUX9xHdoZSQjWH1G5-gbo7fLqSD83PyFqKisCGy-eJGWfmH3ftHLnz2msoPpfW6QenozLL1koG1liHuFxhY4neRtzgeHLjKuXD111O75ael8o9tfAxtZcqtjsoTEEj8UaVaaJAUzkRAUdbVgv/s728-e1000/javascript.png)


A critical security vulnerability has been disclosed in the Quarkus Java framework that could be potentially exploited to achieve remote code execution on affected systems.


Tracked as [CVE-2022-4116](https://nvd.nist.gov/vuln/detail/CVE-2022-4116) (CVSS score: 9.8), the shortcoming could be trivially abused by a malicious actor without any privileges.


"The vulnerability is found in the Dev UI Config Editor, which is vulnerable to drive-by localhost attacks that could lead to remote-code execution (RCE)," Contrast Security researcher Joseph Beeton, who reported the bug, [said](https://www.contrastsecurity.com/security-influencers/localhost-attack-against-quarkus-developers-contrast-security) in a write-up.


Quarkus, developed by Red Hat, is an [open source project](https://quarkus.io/about/) that's used for creating Java applications in [containerized](https://en.wikipedia.org/wiki/Containerization_(computing)) and serverless environments.


It's worth pointing out that the [issue](https://access.redhat.com/security/cve/CVE-2022-4116) only impacts developers who are running Quarkus and are tricked into visiting a specially crafted website, which is embedded with malicious JavaScript code designed to install or execute arbitrary payloads.


[![Quarkus Java framework](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEi_yF009zGBPsk4niV0dcWjA5afDzar1fokz6CfD1s8bmwZqybExYk5GoTfjEAk8H7fKVU67S-gEOtcONtJvPowAQ7KarQ9zSObE_yf1WzbbjsIcTxyusPd4HgjuLyrr1mnH71gF9TaFcImDzPeVwEnYs4Xk1tnvuU5aY7xBzQOdpBFprKWMYLLpstI/s728-e1000/java-code.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEi_yF009zGBPsk4niV0dcWjA5afDzar1fokz6CfD1s8bmwZqybExYk5GoTfjEAk8H7fKVU67S-gEOtcONtJvPowAQ7KarQ9zSObE_yf1WzbbjsIcTxyusPd4HgjuLyrr1mnH71gF9TaFcImDzPeVwEnYs4Xk1tnvuU5aY7xBzQOdpBFprKWMYLLpstI/s728-e100/java-code.png)
This could take the form of a spear-phishing or a watering hole attack without requiring any further interaction on the part of the victim. Alternatively, the attack can be pulled off by serving rogue ads on popular websites frequented by developers.


The [Dev UI](https://quarkus.io/guides/dev-ui), which is offered through a [Dev Mode](https://quarkus.io/guides/dev-mode-differences), is bound to [localhost](https://en.wikipedia.org/wiki/Localhost) (i.e., the current host) and allows a developer to monitor the status of an application, change the configuration, migrate databases, and clear caches.


Because it's restricted to the developer's local machine, the Dev UI also lacks crucial security controls like authentication and cross-origin resource sharing ([CORS](https://web.dev/cross-origin-resource-sharing/)) to prevent a fraudulent website from reading another site's data.


The problem identified by Contrast Security lies in the fact that the JavaScript code hosted on a malware-laced website can be weaponized to modify the Quarkus application configuration via an [HTTP POST request](https://developer.mozilla.org/en-US/docs/Web/HTTP/CORS#simple_requests) to trigger code execution.


"While it only affects Dev Mode, the impact is still high, as it could lead to an attacker getting local access to your development box," Quarkus [noted](https://quarkus.io/blog/quarkus-2-14-2-final-released/) in an independent advisory.


Users are recommended to upgrade to version 2.14.2.Final and 2.13.5.Final to safeguard against the flaw. A potential workaround is to move all the non-application endpoints to a random root path.


  





## Tags:
***CVE's***: CVE-2022-4116

### Autogenerated tags:
quarkus website
