# Researchers Uncover Flaws in Python Package for AI Models and PDF.js Used by Firefox
## Researchers uncover critical security flaws in two widely used software packages, llama_cpp_python for AI models and PDF.js used by the Firefox.
## Information:

+ Link: https://thehackernews.com/2024/05/researchers-uncover-flaws-in-python.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 21 May 2024, 15:52
+ Date scraped: 21 May 2024, 11:07

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg2VqOkAZrz_HIQstJ1Xqey1yQxhbv4BPE3ZRxcFvPmNbbFvEGjwOuPq_EJFXuusvUJeyWr9bLpcFMuY0k2QRmwsTi4vlCAm1qxHoNnaZCa8bjafLYFSOiOjQs0KQW2RrysWZdTY9755sPGC9MD0vHTYGYqPwQXxU_s7_-gowaxvMnA32n6E369yDP3ovN0/s728-rw-e365/pdf.png)


A critical security flaw has been disclosed in the [llama\_cpp\_python](https://pypi.org/project/llama-cpp-python/) Python package that could be exploited by threat actors to achieve arbitrary code execution.


Tracked as [CVE-2024-34359](https://nvd.nist.gov/vuln/detail/CVE-2024-34359) (CVSS score: 9.7), the flaw has been codenamed **Llama Drama** by software supply chain security firm Checkmarx.


"If exploited, it could allow attackers to execute arbitrary code on your system, compromising data and operations," security researcher Guy Nachshon [said](https://checkmarx.com/blog/llama-drama-critical-vulnerability-cve-2024-34359-threatening-your-software-supply-chain/).


llama\_cpp\_python, a Python binding for the [llama.cpp library](https://github.com/ggerganov/llama.cpp), is a popular package with over 3 million downloads to date, allowing developers to integrate AI models with Python. 


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiuUUskkMH9dUT3LF77_Q_irGuaE4LGjp-Am2Ls_UzGJ5EBnZHfuFiSvKs4OPE5KmfedBHcuZZVHS4Bh48UJx8brpwtg6Vr2Gepbaw-lGMIm9HjUhyphenhyphen2W5DVm5-ymwPS691Ie32TrCqFIv6SxNRA-jOKCKZrOB5dV7BfL0zVAhOO0neNkP9yv-XePBU1hN_0/s728-e365/wing-d.png)](https://thehackernews.uk/third-party-risk-management-saas)
Security researcher Patrick Peng (retr0reg) has been credited with discovering and reporting the flaw, which has been addressed in version 0.2.72.


The [core issue](https://github.com/abetlen/llama-cpp-python/security/advisories/GHSA-56xg-wfcc-g829) stems from the misuse of the Jinja2 template engine within the llama\_cpp\_python package, allowing for server-side template injection that leads to remote code execution by means of a specially crafted payload.


"The exploitation of this vulnerability can lead to unauthorized actions by attackers, including data theft, system compromise, and disruption of operations," Checkmarx said.


"The discovery of CVE-2024-34359 serves as a stark reminder of the vulnerabilities that can arise at the confluence of AI and supply chain security. It highlights the need for vigilant security practices throughout the lifecycle of AI systems and their components."


Code Execution Flaw in PDF.js[#](#code-execution-flaw-in-pdfjs)
---------------------------------------------------------------


The development follows the discovery of a high-severity flaw in Mozilla's PDF.js JavaScript library ([CVE-2024-4367](https://nvd.nist.gov/vuln/detail/CVE-2024-4367)) that could allow the execution of arbitrary code.


"A type check was missing when handling fonts in PDF.js, which would allow arbitrary JavaScript execution in the PDF.js context," Mozilla [said](https://www.mozilla.org/en-US/security/advisories/mfsa2024-21/#CVE-2024-4367) in an advisory.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg_WRs2jRYPNRPdVnIJ52g0Zo3TY_c0FSwk8ZZN085hqm-nXig4b7WIZCpqdHexadU4EmZ402vX1EghcAxIZGa9lwLkWAPPYzPbg1gc5UZCbvTtOHQ3ozwiQAgJ1ahKFoOp8SZl-JN8_URGwiu9aTe5U2wiVHGEetM-S7kKkmgPMNdL_83d5HTJrLm7iBp6/s728-e365/cis-d.png)](https://thehackernews.uk/cis-hardened-images)
Codean Labs, which [characterized](https://codeanlabs.com/blog/research/cve-2024-4367-arbitrary-js-execution-in-pdf-js/) the flaw as an "oversight in a specific part of the font rendering code," said it permits an attacker to execute JavaScript code as soon as a malware-laced PDF document is opened in the Firefox browser.


[![AI Models and PDF.js](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhHSiDBK_n8xc1fYPCye_dmYud54K-x0FjbYrpEHnwW6iIT1SnTIiLY-w1v19bIDdBhYG4-vRxFEFkaUY8ioHMtCrCwMlrN6QBzivhJAPpexIEQyLYgkDD5U6GzI0Br4Wm5xY8xCtRqa22srEOvmLHmvosqRaTaiVWN2WqeO4LFCIAbV9v7ItETDSupvf-b/s728-rw-e365/exploit.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhHSiDBK_n8xc1fYPCye_dmYud54K-x0FjbYrpEHnwW6iIT1SnTIiLY-w1v19bIDdBhYG4-vRxFEFkaUY8ioHMtCrCwMlrN6QBzivhJAPpexIEQyLYgkDD5U6GzI0Br4Wm5xY8xCtRqa22srEOvmLHmvosqRaTaiVWN2WqeO4LFCIAbV9v7ItETDSupvf-b/s728-rw-e365/exploit.png)
The issue has been addressed in Firefox 126, Firefox ESR 115.11, and Thunderbird 115.11 shipped last week. It has also been resolved in the npm module [pdfjs-dist version 4.2.67](https://www.npmjs.com/package/pdfjs-dist?activeTab=versions) released on April 29, 2024.


"Most wrapper libraries like react-pdf [have also released](https://github.com/wojtekmaj/react-pdf/discussions/1786) patched versions," security researcher Thomas Rinsma said. "Because some higher level PDF-related libraries statically embed PDF.js, we recommend recursively checking your node\_modules folder for files called pdf.js to be sure."



  





## Tags:
***CVE's***: CVE-2024-4367 CVE-2024-34359

### Autogenerated tags:
pdf.js llama_cpp_python javascript firefox
