# Browser-in-the-Browser Attack Makes Phishing Nearly Invisible
## Can we trust web browsers to protect us, even if they say “https?” Not with the novel BitB attack, which fakes popup SSO windows to phish away credentials for Google, Facebook and Microsoft, et al.
## Information:

+ Link: https://kasperskycontenthub.com/threatpost-global/?p=179014
+ Source: ThreatPost
+ Author: Lisa Vaas
+ Date published: 21 March 2022, 23:57
+ Date scraped: 22 March 2022, 00:00

## Article:
![Main article image](https://media.threatpost.com/wp-content/uploads/sites/103/2022/03/21195539/Invisible-man-scaled-e1647906959971.jpeg)


We’ve had it beaten into our brains: Before you go wily-nily clicking on a page, check the URL. First things first, the tried-and-usually-but-[not-always-true](https://www.akamai.com/blog/security/watch-your-step-the-prevalence-of-idn-homograph-attacks) [advice](https://threatpost.com/dnspooq-flaws-allow-dns-hijacking-of-millions-of-devices/163163/) goes, check that the site’s URL shows “[https](https://en.wikipedia.org/wiki/HTTPS),” indicating that the site is secured with [TLS/SSL](https://threatpost.com/nsa-urges-sysadmins-to-replace-obsolete-tls-protocols/162814/) encryption.


If only it were that easy to avoid phishing sites. In reality, URL reliability hasn’t been absolute for a long time, given things like [homograph attacks](https://www.akamai.com/blog/security/watch-your-step-the-prevalence-of-idn-homograph-attacks) that swap in [similar-looking characters](https://threatpost.com/convincing-google-impersonation-opens-door-to-mitm-phishing/153745/) in order to create new, identical-looking but malicious URLs, as well as [DNS hijacking](https://threatpost.com/dnspooq-flaws-allow-dns-hijacking-of-millions-of-devices/163163/), in which Domain Name System (DNS) queries are [subverted](https://www.cloudflare.com/en-ca/learning/security/global-dns-hijacking-threat/).


[![Infosec Insiders Newsletter](https://media.threatpost.com/wp-content/uploads/sites/103/2021/07/10165815/infosec_insiders_in_article_promo.png)](https://threatpost.com/infosec-insider-subscription-page/?utm_source=ART&utm_medium=ART&utm_campaign=InfosecInsiders_Newsletter_Promo/)


Now, there’s one more way to trick targets into coughing up sensitive info, with a coding ruse that’s invisible to the naked eye. The novel phishing technique, [described](https://mrd0x.com/browser-in-the-browser-phishing-attack/?no-cache=1) last week by a penetration tester and security researcher who goes by the handle mr.d0x, is called a browser-in-the-browser (BitB) attack.


The novel method takes advantage of third-party single sign-on ([SSO](https://en.wikipedia.org/wiki/Single_sign-on)) options embedded on websites that issue popup windows for authentication, such as “Sign in with Google,” Facebook, Apple or Microsoft.


The researcher used Canva as an example: In the log-in window for Canva shown below, the popup asks users to authenticate via their Google account.


[![](https://media.threatpost.com/wp-content/uploads/sites/103/2022/03/21194343/Legit-login-to-Canva-e1647906237286.png)](https://media.threatpost.com/wp-content/uploads/sites/103/2022/03/21194343/Legit-login-to-Canva-e1647906237286.png)Login to Canva using Google account credentials. Source: mr.d0x


## It’s Easy to Fabricate an Identical, Malicious Popup


These days, SSO popups are a routine way to authenticate when you sign in.


But according to mr.d0x’s post, completely fabricating a malicious version of a popup window is a snap: It’s “quite simple” using basic HTML/CSS, the researcher said. The concocted popups simulate a browser window within the browser, spoofing a legitimate domain and making it possible to stage convincing phishing attacks.


“Combine the window design with an iframe pointing to the malicious server hosting the phishing page, and [it’s] basically indistinguishable,” mr.d0x wrote. The report provided an image, included below, that shows a side-by-side of a fake window next to the real window.


[![](https://media.threatpost.com/wp-content/uploads/sites/103/2022/03/21194525/real-v-fake-login-pages-e1647906342234.png)](https://media.threatpost.com/wp-content/uploads/sites/103/2022/03/21194525/real-v-fake-login-pages-e1647906342234.png)Nearly identical real vs. fake login pages. Source: mr.d0x.


“Very few people would notice the slight differences between the two,” according to the report.


JavaScript can make the window appear on a link, button click or page loading screen, the report continued. As well, libraries – such as the popular JQuery JavaScript library – can make the window appear visually appealing … or, at least, visually bouncy, as depicted in the .gif provided in the researcher’s demo and shown below.


[![](https://media.threatpost.com/wp-content/uploads/sites/103/2022/03/21154801/BitB-demo.gif)](https://media.threatpost.com/wp-content/uploads/sites/103/2022/03/21154801/BitB-demo.gif)BitB demo. Source: mr.d0x.


## Hovering Over Links: Another Easily Fooled Security Safeguard


The BitB attack can also flummox those who use the trick of hovering over a URL to figure out if it’s legitimate, the researcher said: If JavaScript is permitted, the security safeguard is rendered ineffective.


The writeup pointed to how HTML for a link generally looks, as in this sample:


<a href=”https://gmail.com”>Google</a>


“If an onclick event that returns false is added, then hovering over the link will continue to show the website in the href attribute but when the link is clicked then the href attribute is ignored,” the researcher explained.


“We can use this knowledge to make the pop-up window appear more realistic,” they said, providing this visually undetectable HTML trick:



> <a href=”https://gmail.com” onclick=”return launchWindow();”>Google</a>
> 
> 



> function launchWindow(){
> 
> 



> // Launch the fake authentication window
> 
> 



> return false; // This will make sure the href attribute is ignored
> 
> 



> }
> 
> 


## All the More Reason for MFA


Thus does the BitB technique undercut both the fact that a URL contains the “https” encryption designation as a trustworthy site, as well as the hover-over-it security check.


“With this technique we are now able to up our phishing game,” the researcher concluded.


Granted, a target user would still need to land on a threat actor’s website for the malicious popup window to be displayed. But once the fly has landed in the spider’s web, there’s nothing alarming to make them struggle against the idea of handing over SSO credentials.


“Once landed on the attacker-owned website, the user will be at ease as they type their credentials away on what appears to be the legitimate website (because the trustworthy URL says so),” mr.d0x wrote.


But there are other security checks that the BitB attack would have to overcome: namely, those that don’t rely on the fallibility of human eyeballs. Password managers, for example, probably wouldn’t autofill credentials into a fake BitB popup because software wouldn’t interpret the as a real browser window.


Lucas Budman, CEO of passwordless workforce identity management firm TruU, said that with these attacks, it’s just a matter of time before people fork over their passwords to the wrong person, thereby relegating multifactor authentication (MFA) to “a single factor as the password is already compromised.”


Budman told Threatpost on Monday that password reuse makes it particularly dangerous, including sites that aren’t MFA-enabled.


“As long as username/password is used, even with 2FA, it is completely vulnerable to such attacks,” he said via email. “As bad actors get more sophisticated with their attacks, the move to passwordless MFA is more critical now than ever. Eliminate the attack vector by eliminating the password with password-less MFA.”


By passwordless MFA, he is, of course, referring to ditching passwords or other knowledge-based secrets in favor of providing a secure proof of identity through a registered device or token. GitHub, for one, made a move on this front in May 2021, when it [added support](https://threatpost.com/github-security-keys-passwords/166054/) for FIDO2 security keys for Git over SSH in order to fend off account hijacking and further its plan to stick a fork in the security bane of passwords.


The portable [FIDO2](https://threatpost.com/active-malware-campaign-html-smuggling/158439/) fobs are used for SSH authentication to secure Git operations and to forestall the misery that unfurls when private keys accidentally get lost or pilfered, when malware tries to initiate requests without user approval or when researchers come up with newfangled ways to bamboozle eyeballs – BitB being a case in point.


***Moving to the cloud? Discover emerging cloud-security threats along with solid advice for how to defend your assets with our*** [***FREE downloadable eBook***](https://bit.ly/3Jy6Bfs)***, “Cloud Security: The Forecast for 2022.”*** ***We explore organizations’ top risks and challenges, best practices for defense, and advice for security success in such a dynamic computing environment, including handy checklists.***





## Tags:
***urls***: https://gmail.com

### Autogenerated tags:
window mr.d0x bitb url popup phishing website mfa sso canva
