# Google Patches Chrome’s Fifth Zero-Day of the Year
## An insufficient validation input flaw, one of 11 patched in an update this week, could allow for arbitrary code execution and is under active attack
## Information:

+ Link: https://kasperskycontenthub.com/threatpost-global/?p=180432
+ Source: ThreatPost
+ Author: Elizabeth Montalbano
+ Date published: 18 August 2022, 14:31
+ Date scraped: 18 August 2022, 15:02

## Article:
![Main article image](https://media.kasperskycontenthub.com/wp-content/uploads/sites/103/2019/07/31115247/chrome_patch.jpg)


Google has patched the fifth actively exploited zero-day vulnerability discovered in Chrome this year as one in a series of fixes included in a stable channel update released Wednesday.


The bug, tracked as [CVE-2022-2856](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-2856) and rated as high on the Common Vulnerability Scoring System (CVSS), is associated with “insufficient validation of untrusted input in Intents,” according to [the advisory](https://chromereleases.googleblog.com/2022/08/stable-channel-update-for-desktop_16.html) posted by Google.


Google credits Ashley Shen and Christian Resell of its Google Threat Analysis Group (TAG) for reporting the zero-day bug, which could allow for arbitrary code execution, on July 19. The advisory also unveiled 10 other patches for various other Chrome issues.


Intents are a deep linking feature on the Android device within the Chrome browser that replaced URI schemes, which previously handled this process, [according to Branch](https://branch.io/glossary/chrome-intents/), a company that offers various linking options for mobile applications.


“Instead of assigning window.location or an iframe.src to the URI scheme, in Chrome, developers need to use their intent string as defined in this document,” the company explained on its website. Intent “adds complexity” but “automatically handles the case of the mobile app not being installed” within links, according to the post.


Insufficient validation is associated with input validation, a frequently-used technique for checking potentially dangerous inputs to ensure that they are safe for processing within the code, or when communicating with other components, [according to MITRE’s Common Weakness Enumeration site](https://cwe.mitre.org/data/definitions/20.html).



[![](https://media.threatpost.com/wp-content/uploads/sites/103/2021/07/10165815/infosec_insiders_in_article_promo.png)](https://threatpost.com/infosec-insider-subscription-page/?utm_source=ART&utm_medium=ART&utm_campaign=InfosecInsiders_Newsletter_Promo/)

“When software does not validate input properly, an attacker is able to craft the input in a form that is not expected by the rest of the application,” according to a post on the site. “This will lead to parts of the system receiving unintended input, which may result in altered control flow, arbitrary control of a resource, or arbitrary code execution.”


**Fending Off Exploits**


As is typical, Google did not disclose specific details of the bug until it is widely patched to avoid threat actors taking further advantage of it, a strategy that one security professional noted is a wise one.


“Publicizing details on an actively exploited zero-day vulnerability just as a patch becomes available could have dire consequences, because it takes time to roll out security updates to vulnerable systems and attackers are champing at the bit to exploit these types of flaws,” observed Satnam Narang, senior staff research engineer at cybersecurity firm [Tenable,](https://www.tenable.com/) in an email to Threatpost.


Holding back info is also sound given that other Linux distributions and browsers, such as Microsoft Edge, also include code based on Google’s Chromium Project. These all could be affected if an exploit for a vulnerability is released, he said.


“It is extremely valuable for defenders to have that buffer,” Narang added.


While the majority of the fixes in the update are for vulnerabilities rated as high or medium risk, Google did patch a critical bug tracked as [CVE-2022-2852](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-2852), a use-after-free issue in FedCM reported by Sergei Glazunov of Google Project Zero on Aug. 8. FedCM—short for the Federated Credential Management API–provides a use-case-specific abstraction for federated identity flows on the web, [according to Google](https://developer.chrome.com/docs/privacy-sandbox/fedcm/).


**Fifth Chrome 0Day Patch So Far**


The zero-day patch is the fifth Chrome bug under active attack that Google has patched so far this year.


In July, the company fixed an [actively exploited heap buffer overflow flaw](https://threatpost.com/actively-exploited-chrome-bug/180118/) tracked as [CVE-2022-2294](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-2294) in WebRTC, the engine that gives Chrome its real-time communications capability, while in May it was a separate buffer overflow flaw tracked as [CVE-2022-2294](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-2294) and under active attack that got slapped with a patch.


In April, Google patched [CVE-2022-1364](https://cve.mitre.org/cgi-bin/cvename.cgi?name=2022-1364), a type confusion flaw affecting Chrome’s use of the V8 JavaScript engine on which attackers already had pounced. The previous month a separate type-confusion issue in V8 tracked as [CVE-2022-1096](https://cve.mitre.org/cgi-bin/cvename.cgi?name=2022-1096) and under active attack also [spurred a hasty patch](https://threatpost.com/google-chrome-bug-actively-exploited-zero-day/179161/).


February saw a fix for the first of this year’s Chrome zero-days, a use-after-free flaw in Chrome’s Animation component tracked as [CVE-2022-0609](https://nvd.nist.gov/vuln/detail/CVE-2022-0609) that already [was under attack](https://threatpost.com/google-chrome-zero-day-under-attack/178428/). Later [it was revealed](https://threatpost.com/google-chrome-zero-day-bugs-exploited-weeks-ahead-of-patch/179103/) that North Korean hackers were exploiting the flaw weeks before it was discovered and patched.








## Tags:
***CVE's***: CVE-2022-2856 CVE-2022-1364 CVE-2022-2294 CVE-2022-1096 CVE-2022-2852 CVE-2022-0609

### Autogenerated tags:
google zero-day
