# Analyzing a Facebook Profile Stealer Written in Node js
## We analyze an information stealer written in Node.js, packaged into an executable, exfiltrated stolen data via both Telegram bot API and a C&C server, and employed GraphQL as a channel for C&C communication.
## Information:

+ Link: https://www.trendmicro.com/en_us/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js.html
+ Source: Trend Micro
+ Author: Jaromir Horejsi
+ Date published: 05 September 2023, 00:00
+ Date scraped: 05 September 2023, 09:00

## Article:
![Main article image](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/thumbnails/23/fb-stealer-cov.png)






During our [previous analysis of a campaign](https://www.trendmicro.com/en_us/research/23/h/profile-stealers-spread-via-llm-themed-facebook-ads.html) involving a Facebook stealer, we discovered another interesting stealer. It was written in [Node.js](https://nodejs.org/en), packaged into an executable, exfiltrated stolen data via both [Telegram bot](https://telegram.org/blog/bot-revolution) API and a command-and-control (C&C) server, and employed [GraphQL](https://graphql.org/) as a channel for C&C communication. This blog entry investigates this new stealer and provides an in-depth analysis of its routines and capabilities.


Infection vector
================


Recent campaign
---------------


Like the earlier campaign, we noticed that this stealer was distributed via malicious Large Language Model (LLM)-themed Facebook ads. These malicious ads contain a link to a page hosted on [Google Sites](https://sites.google.com/), which then contains a link to an archive hosted on [Trello](https://trello.com/) (an online project and task management tool).






[![Figure 1. A fake LLM-themed website offering a MetaAI package](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer1.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer1.png)
Figure 1. A fake LLM-themed website offering a MetaAI package







Previous campaigns
------------------


Searching further back, we managed to find older campaigns that abused Trello to host archives containing stealers. The keywords used in the file names include “marketing specialist,” “marketing recruitment,” “CV sample,” “advertising campaign,” “marketing project,” and the names of services like Google, Facebook, and TikTok.






[![Figure 2. Malicious hosted packages in the “hiring” list](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer2.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer2.png)
Figure 2. Malicious hosted packages in the “hiring” list






Another example showed a fake website impersonating the CapCut video editor that was used to trick victims into downloading the package.






[![Figure 3. Fake website pretending to offer the CapCut video editor](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer3.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer3.png)
Figure 3. Fake website pretending to offer the CapCut video editor






[![Figure 4. The stealer hosted on Trello has an archive name that contains the name of a video editing tool](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer4.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer4.png)
Figure 4. The stealer hosted on Trello has an archive name that contains the name of a video editing tool






Node.js packaging
=================


The archive will usually contain a single executable file with a size between 50 – 70MB. Note that the JavaScript code of the stealer itself is quite small (less than 100KB), however, embedding the [Node.js](https://nodejs.org/en) binary and all packages with [pkg](https://www.npmjs.com/package/pkg) significantly inflates the overall size. As a result of packaging, the developer gets a single file that doesn’t need to download and install any dependencies. During packaging, the pkg uses a [source map](https://firefox-source-docs.mozilla.org/devtools-user/debugger/how_to/use_a_source_map/index.html), where all the sources are combined into one file.


The offsets and lengths of this source map can be found at the end of the packaged executable file. Researchers can then use the provided information to extract the desired components from the package. As shown in figure 5, *app.js* (the main file) is the starting point of the application.






[![Figure 5. The source map containing list of all files contained within the package.](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer5.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer5.png)
Figure 5. The source map containing list of all files contained within the package.






The stealer
===========


When the stealer is executed, it runs its main function that steals cookies and credentials from several [Chromium](https://www.chromium.org/)-based web browsers, then exfiltrates the data to the C&C server and to the Telegram bot. It also subscribes the client to the C&C server running [GraphQL](https://graphql.org/). When the C&C server sends a message to the client, the stealing function will run again.


The main function routine
-------------------------


1. The main function prevents the stealer from running too often. The stealer saves the timestamp of its last run to a text file in the home directory (*c:\Users\<username>).* If the time elapsed from the last run is less than approximately 30 minutes (or 0x1cd6d0 ms = 1890000 ms = 1890 s = 31.5 mins, to be exact), the stealing routine is skipped for this run.
2. It checks for the backup C&C server address, which is encoded using Base64, by querying *<C&C server>/bk/map.txt*. This backup response is also saved in another text file in the user home directory for future use.
3. It retrieves the external IP address by querying the *whoer.net* website.
4. It initializes [graphql-ws](https://www.npmjs.com/package/graphql-ws), [ws](https://www.npmjs.com/package/ws), and other necessary libraries to enable [GraphQL](https://graphql.org/) over [websockets](https://developer.mozilla.org/en-US/docs/Web/API/WebSockets_API) communication with the C&C server. It then initializes the [Apollo Client](https://www.npmjs.com/package/@apollo/client) to access a [self-hosted](https://www.apollographql.com/docs/graphos/quickstart/self-hosted) supergraph.
5. It [subscribes](https://www.apollographql.com/docs/react/data/subscriptions) to the C&C server to enable it to push messages to the victim’s machine. It subscribes to observables with callbacks using the [zen-observable](https://github.com/zenparsing/zen-observable) library. The subscribed operation contains an external IP address as a parameter, with the response (the content of the push message) returning the string value \_id.
6. It runs the information theft process.
7. It then copies itself to the home directory and sets autorun persistence.


Handling push messages
----------------------


If a threat actor pushes a message to the infected client, the received message has the  JSON format seen in Figure 6. The purpose of the a message is to assign an \_id to the infected client.






[![Figure 6. The format of the received push message](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer6.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer6.png)
Figure 6. The format of the received push message






After the client receives an \_id, it then sends another message back to the C&C server to modify some back-end data (called a mutation in GraphQL terminology). The mutation operation contains a previously assigned \_id, followed by a status message concatenated with the current date and time. The theft of credentials from all browsers in the targeted machine then follows.






[![Figure 7. The mutation operation in which the client sends the status message to the server](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer7.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer7.png)
Figure 7. The mutation operation in which the client sends the status message to the server






After the stealing process is completed, the client sends another status message to the server stating that the stealing process has been completed. In the case of a server pushing a message during the stealing process, the client responds with a “wait for the completion” message.


The reason for the implementation of handling such messages is the activation of the stealing process. The threat actor maintains an IP address list of infected clients that are just waiting for activation (by receiving a message). After the threat actor pushes a message to the clients, the stealing process restarts.


The information theft process
-----------------------------


The stealer focuses on the following web browsers:


* Microsoft Edge
* Google Chrome
* Opera / OperaGX
* Brave


For each browser, the stealer searches for available profiles in the [*User Data*](https://chromium.googlesource.com/chromium/src/+/master/docs/user_data_dir.md) folder. It then collects the user home path, the profile path, the *User Data* path, and version information from the \*User Data\Last Version* file. Next, it extracts the encrypted key (used to decrypt Chrome cookies and passwords) from \*User Data\Local State*  and decrypts it. Finally, it will kill the browser process.


For each available profile, the stealer gets all saved cookies database from *<profile>\Network\Cookies*. It then checks if a Facebook cookie named [*xs*](https://cookiedatabase.org/cookie/facebook/xs/)is present. This cookie is a session ID that indicates whether a user is logged in to Facebook for that profile. If this cookie is not found, it skips the profile.


It extracts all cookies belonging to Facebook, Google, and Outlook (live.com) and decrypts all of them with a key previously obtained from *\User Data\Local State*. It also retrieves the database of all saved login credentials from *<profile path>\Login Data*.


Furthermore, the stealer decrypts all Facebook, Google, and Outlook logins (usernames, emails and passwords) also using a key obtained from *\User Data\Local State*.


It then checks if the MetaMask extension exists in *<profile path>\Local Extension Settings\*, after which it packs the whole MetaMask extension directory into a zip archive and exfiltrates it to the Telegram bot.


It gets Facebook’s [c\_user](https://cookiedatabase.org/cookie/facebook/c_user/) cookie and additional browser information such as operating system, version, and architecture. The stealer will also attempt to steal [Facebook’s access token](https://developers.facebook.com/docs/facebook-login/guides/access-tokens/). If this is unsuccessful, it will exfiltrate Facebook cookies, browser names, executable paths, saved logins, IP addresses, and country codes. The targeted profile is then skipped, with the stealer proceeding to another profile.


It then exfiltrates the following in order via GET requests to C&C server:


1. Facebook identity numbers, full usernames, email addresses, birthdays, access tokens, Facebook cookies, browser names, executable paths, saved logins, IP addresses, and country codes
2. Gmail credentials and cookies
3. Outlook credentials and cookies
4. Additional Facebook information, such as email addresses and location information
5. Business account information, such as usernames and identifiers.  For each business account, it will steal the name, ad account limit, creation time, business ID, permitted roles, verification status, and number of business users associated with the business.
6. Page information, including usernames and [page access token](https://developers.facebook.com/docs/pages/access-tokens/)s
7. Ad account information, which includes usernames. For each ad accounts, the stealer extracts ad account IDs, [ad account agencies](https://developers.facebook.com/docs/marketing-api/reference/ad-account/agencies/), spending limits, extended credits (invoice and how often it is billed), currency ratio to USD, time zones, next billing dates, the creation time, [billing threshold](https://www.facebook.com/business/help/776240779095515)s, balances, payment cards, payment card expiration dates, payment card verification status, ad account insights, and account status


Most likely for backup purposes, previously extracted information is also saved into a text file and sent to the Telegram bot.


Exfiltration to the C&C server
------------------------------


The exfiltration of stolen data to the C&C server is done via GET request to a randomly generated path (*<server>/image/<random 26-character ID>.png*). The exfiltrated content is passed inside the [authorization header](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Authorization).






[![Figure 8. GET request with the exfiltrated data](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer8.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer8.png)
Figure 8. GET request with the exfiltrated data






The payload in the authorization header is encrypted and hex-encoded. The author likely intended to use a simple string for the encryption, as suggested by the following snippet.






[![Figure 9. A passphrase used to generate the actual encryption key](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer9.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer9.png)
Figure 9. A passphrase used to generate the actual encryption key






However, in the code, the encryption and decryption is implemented using the improper/illogical use of map/[reduce](https://www.w3schools.com/jsref/jsref_reduce.asp). This means that all characters in passphrase are XORed, which in turn makes the encryption a single-byte XOR encryption.






[![Figure 10. For the hardcoded passphrase “haha123444”, the generated encryption key is just a single byte 0x04.](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer10.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer10.png)
Figure 10. For the hardcoded passphrase “haha123444”, the generated encryption key is just a single byte 0x04.






Anti-analysis features
----------------------


To make analysis by security researchers more difficult, the application hides its console window by calling the hideConsole command from the [node-hide-console-window](https://www.npmjs.com/package/node-hide-console-window) package.


In addition, selected methods from [console](https://developer.mozilla.org/en-US/docs/Web/API/console) objects are [overwritten with empty functions](https://stackoverflow.com/questions/1215392/how-to-quickly-and-conveniently-disable-all-console-log-statements-in-my-code) to suppress logging error and debug messages.






[![Figure 11. List of methods overwritten by empty function to suppress logging.](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer11.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer11.png)
Figure 11. List of methods overwritten by empty function to suppress logging.






Threat actor background
=======================


Within the code, we noticed several comments, status messages and variable names in Vietnamese language, suggesting that the author(s) of this malware may have knowledge of this language.






[![Figure 12. List of a few selected variable names in Vietnamese language](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer12.png)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/fb-stealer12.png)
Figure 12. List of a few selected variable names in Vietnamese language






Conclusion
==========


The sheer amount of information pilfered by stealers such as the one we just analyzed in this blog entry means that users must be extra careful since these kinds of malware often results in significant compromise and could lead to being targeted for follow-up attacks. As always, vigilance and proper cybersecurity hygiene go a long way in ensuring that a person’s online activities are safe and secure.


Here are some steps users can take to minimize the risks associated with malware that use malicious ads for distribution:


1. Avoid clicking on ads, especially if they seem suspicious or offer something that seems too good to be true.
2. Be cautious when dealing with pop-up windows or ads that ask for personal information. Never provide sensitive information unless absolutely sure of the legitimacy of the app or website being visited.
3. Invest in reputable antivirus and anti-malware technologies. These tools can help detect and mitigate the impact of malicious software that might be delivered through ads.
4. Learn how to recognize the most common signs of malicious ads, such as typographical errors, poor grammar, and offers that seem too good to be true.
5. When downloading or clicking on ads that promote software, ensure they come from reputable sources. Stick to official app stores and trusted websites when downloading tools and apps.


Indicators of Compromise
========================


The indicators of compromise for this entry can be found [here](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/analyzing-a-facebook-profile-stealer-written-in-node-js/ioc-analyzing-a-facebook-profile-stealer-written-in-node.js).








## Tags:


### Autogenerated tags:
facebook c&c google website ip usernames graphql _id node.js exfiltrated
