# Examining the Activities of the Turla APT Group
## We examine the campaigns of the cyberespionage group known as Turla over the years, with a special focus on the key MITRE techniques and the corresponding IDs associated with the threat actor group.
## Information:

+ Link: https://www.trendmicro.com/en_us/research/23/i/examining-the-activities-of-the-turla-group.html
+ Source: Trend Micro
+ Author: Srivathsa Sharma
+ Date published: 22 September 2023, 00:00
+ Date scraped: 22 September 2023, 09:01

## Article:
![Main article image](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/thumbnails/23/Turla-cover.png)






In this blog entry, we examine the campaigns of the [cyberespionage group known as Turla](https://www.trendmicro.com/vinfo/pl/security/news/cyber-attacks/cyberespionage-group-turla-deploys-backdoor-ahead-of-g20-summit) over the years, with a special focus on the key MITRE techniques and the corresponding IDs associated with the threat actor group.


**An introduction to Turla**


Regarded as a highly sophisticated advanced persistent threat (APT) group, the Russian-based Turla has been suspected to be [operational since at least 2004](https://unit42.paloaltonetworks.com/turla-pensive-ursa-threat-assessment/).


Turla’s group names are infamously titled after its top-class rootkits such as Snake, Venomous Bear, WhiteBear, Uroburos, Group 88, and Waterbug, all known for targeting government entities, intelligence agencies, as well as the military, educational, research, and pharmaceutical industries around the world. Like other APT groups, Turla possesses its own specifically-designed, complex tools. However, it is the threat actor’s satellite-based command-and-control (C&C) mechanism that it uses in the latter stages of an attack, coupled with its ability to fly under the radar, that makes Turla stand out from its contemporaries.


Unravelling Turla’s activities
==============================


2014
----


August: The “epic” Turla tale
-----------------------------


Although Turla has been known to be active in the wild for several years now, its infection vector had been a question mark. [Research](https://www.kaspersky.com/blog/epic-turla-catching-the-reptiles-tail/14991/) conducted in 2014 indicated a sophisticated multi-stage attack using Epic (a malware family used by Turla), with the campaign being dubbed as Epic Turla. The attacks, which exploited the vulnerabilities [CVE-2013-5065](https://nvd.nist.gov/vuln/detail/CVE-2013-5065) and [CVE-2013-3346](https://nvd.nist.gov/vuln/detail/CVE-2013-3346), employed spear-phishing emails that used Adobe PDF exploits and watering-hole techniques that used Java exploits ([CVE-2012-1723](https://nvd.nist.gov/vuln/detail/CVE-2012-1723))


The major highlight of this campaign was Turla’s use of more complex backdoors like Carbon/Cobra, with the group sometimes using both backdoors as a failover.






[![Figure 1. The MITRE ATT&CK techniques used in the August 2014 campaigns ](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-01.jpg)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-01.jpg)

Figure 1. The MITRE ATT&CK techniques used in the August 2014 campaigns 








Techniques:


* [T1189](https://attack.mitre.org/techniques/T1189/)
* [T1566](https://attack.mitre.org/techniques/T1566/)
* [T1204.002](https://attack.mitre.org/techniques/T1204/002/)


December: Turla targets Linux
-----------------------------


While the previous Turla campaigns were designed to target Windows-based machines, the campaign in August 2014  was the first instance where Turla targeted the Linux operating system. Dubbed as [Penguin Turla](https://securelist.com/the-penquin-turla-2/67962/), the group used a Linux Turla module with a C/C++ executable statically linked against multiple libraries, greatly increasing its file size for this campaign.


2016
----


January: The Waterbug Campaign
------------------------------


A group of threat actors named Waterbug (alleged to be a state-sponsored group) used variants of Trojan.Turla and Trojan.Wipbot to exploit a zero-day vulnerability, specifically the Windows Kernel *NDProxy.sys* local privilege escalation vulnerability [CVE-2013-5065](https://nvd.nist.gov/vuln/detail/cve-2013-5065). A [research](https://docs.broadcom.com/doc/waterbug-attack-group) entry suggested that the attackers used specially crafted emails with malicious attachments and a set of compromised websites to deliver malicious payloads.


2017
----


March: The Carbon backdoor
--------------------------


In 2017, ESET published a research entry on a [sophisticated variant of the Turla malware](https://www.welivesecurity.com/2017/03/30/carbon-paper-peering-turlas-second-stage-backdoor/), a second-stage backdoor known as Carbon. A Carbon attack initially involves the victim either receiving a spear-phishing email or visiting a compromised website, also known as a watering hole.


This is then followed by the installation of a first-stage backdoor such as Tavdig or Skipper. The second-stage backdoor Carbon is then installed on key systems after renaissance activities are completed. The Carbon framework consists of a dropper to install its configuration file, a component to communicate with the C&C server, an orchestrator to handle tasks and move them laterally over the network, and a loader to execute the orchestrator.


May – The Kazuar backdoor
-------------------------


In May 2017, a new backdoor trojan by the name [Kazuar](https://unit42.paloaltonetworks.com/unit42-kazuar-multiplatform-espionage-backdoor-api-access/) was linked to the Turla group. Written using the Microsoft .NET Framework, Kazuar contains highly functional command sets that are capable of remotely loading additional plug-ins.


Kazuar gathers system and malware file name information and creates a mutex to ensure that only one instance of the malware executes on the system at a time. It then adds an LNK file to the Windows startup folder.


Majority of the commands set in Kazuar share similar attributes with other backdoor Trojans. For example, the *tasklist* command uses a Windows Management Instrumentation (WMI) query to obtain running process from Windows while the *info* command is used to gather information about opened windows. Meanwhile, Kazuar’s *cmd* command will run commands using *cmd.exe* for Windows systems and */bin/bash* for Unix systems. These commands strongly suggests that Kazuar was built to be a cross-platform malware targeting both Windows and Unix systems.


Research [conducted in early 2021](https://securelist.com/sunburst-backdoor-kazuar/99981/) revealed several similarities between the Sunburst and Kazuar backdoors.






[![Figure 2. The MITRE ATT&CK techniques used in the Kazuar campaigns](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-02.jpg)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-02.jpg)

Figure 2. The MITRE ATT&CK techniques used in the Kazuar campaigns







Techniques:


* [T1047](https://attack.mitre.org/techniques/T1047/)
* [T147.009](https://attack.mitre.org/techniques/T1547/009/)
* [T1010](https://attack.mitre.org/techniques/T1010/)


August: Emergence of Gazer
--------------------------


In August, Turla unveiled a new second-stage backdoor written in C++ known as [Gazer](https://www.welivesecurity.com/wp-content/uploads/2017/08/eset-gazer.pdf), which relied on watering-hole attacks and spear-phishing campaigns for more precise targeting of victims.


Aside from being stealthier, Gazer was found to have plenty of similarities with the previously used second-stage backdoors such as Carbon and Kazuar. The defining characteristic of this campaign was the insertion of “video-game-relate” sentences throughout the code. Turla encrypts Gazer’s C&C server using its own library for 3DES and RSA.






[![Figure 3. The MITRE ATT&CK technique used in the Gazer campaigns](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-03.jpg)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-03.jpg)

Figure 3. The MITRE ATT&CK technique used in the Gazer campaigns







Techniques:


* [T1573](https://attack.mitre.org/techniques/T1573/)


2018
----


January: Turla adds new tools to its arsenal
--------------------------------------------


An intelligence [report](https://www.ncsc.gov.uk/news/turla-group-malware) from 2018 suggested that Turla used new malicious tools known as Neuron and Nautilus in conjunction with the Snake rootkit to target Windows machines, focusing on mail and web servers in particular. Turla made use of existing Snake victims to scan for ASPX shell, with the commands being passed using encrypted HTTP cookie values. The entry also mentioned that Turla used ASPX shells to gain a foothold into the target system to deploy additional tools.


August: Turla targets Microsoft Outlook
---------------------------------------


Turla [targeted the foreign offices](https://www.welivesecurity.com/wp-content/uploads/2018/08/Eset-Turla-Outlook-Backdoor.pdf) of European governments via a backdoor, with the intention of accessing highly sensitive information. The campaign targeted Microsoft Outlook and The Bat! (a popular mail client primarily used in Eastern Europe) by forwarding all outgoing emails to the attackers. The backdoor used email messages to exfiltrate data, employing specially crafted PDF documents. It also used email messages as a transport layer for its C&C server.


2019
----


June: Turla uses OilRig infrastructure
--------------------------------------


OilRig is an [Iran-linked APT group](https://www.attackiq.com/2022/07/11/oilrig-attack-graphs-emulating-the-iranian-threat-actors-global-campaigns/) that usually targets government agencies and organizations in the Middle East. Previous [research](https://symantec-enterprise-blogs.security.com/blogs/threat-intelligence/waterbug-espionage-governments) suggests that the Turla group compromised a target using OilRig’s infrastructure. The campaign saw the use of a heavily modified, custom variant of the [Mimikatz tool](https://www.trendmicro.com/vinfo/ph/security/news/cybercrime-and-digital-threats/locked-loaded-and-in-the-wrong-hands-legitimate-tools-weaponized-for-ransomware-in-2021), plus a  new set of tools involving several new backdoors. In the later stages of the campaign, Turla group used a different remote procedure call (RPC) backdoor, which included code from the publicly available PowerShell Runner tool to execute PowerShell scripts (without using *powershell.exe*).


2020
----


March: New backdoors written in .NET and Python
-----------------------------------------------


In March 2020, [security researchers observed](https://www.welivesecurity.com/2020/03/12/tracking-turla-new-backdoor-armenian-watering-holes/) Turla targeted multiple Armenian websites using watering-hole attacks. These websites were implanted with malicious JavaScript code, although the access methods used in attack are unknown.


The compromised webpage then delivered the second-stage malicious JavaScript code to fingerprint victim browser and trick them into installing a malicious flash installer. Turla then used NetFlash (a .NET downloader) and PyFlash for its second-stage malware.






[![Figure 4. The MITRE ATT&CK techniques used in the March 2020 campaigns](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-04.jpg)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-04.jpg)

Figure 4. The MITRE ATT&CK techniques used in the March 2020 campaigns







Techniques:


* [T1189](https://attack.mitre.org/techniques/T1189/)
* [T1204](https://attack.mitre.org/techniques/1204/)
* [T1053](https://attack.mitre.org/techniques/T1053/)
* [T1016](https://attack.mitre.org/techniques/T1016/)
* [T1057](https://attack.mitre.org/techniques/T1057/)
* [T1082](https://attack.mitre.org/techniques/T1082/)
* [T1071](https://attack.mitre.org/techniques/T1071/)
* [T1573](https://attack.mitre.org/techniques/T1573/)
* [T1571](https://attack.mitre.org/techniques/T1571/)
* [T1041](https://attack.mitre.org/techniques/T1041/)


May: ComRAT v4
--------------


[ComRAT v4](https://www.welivesecurity.com/2020/05/26/agentbtz-comratv4-ten-year-journey/), also known as Agent.BTZ, is a remote access trojan (RAT) used by Turla and developed using C++ and employing a virtual FAT16 file system that is often used to exfiltrate sensitive documents. It is deployed using existing access methods, such as the PowerStallion PowerShell backdoor. Furthermore, it uses HTTP and emails as C&C channels. 






[![Figure 5. The MITRE ATT&CK techniques used in ComRAT v4 attacks](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-05.jpg)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-05.jpg)

Figure 5. The MITRE ATT&CK techniques used in ComRAT v4 attacks







Techniques:


* [T1059](https://attack.mitre.org/techniques/T1059/)
* [T1053](https://attack.mitre.org/techniques/T1053/)
* [T1055](https://attack.mitre.org/techniques/T1055/)
* [T1069](https://attack.mitre.org/techniques/T1069/)
* [T1033](https://attack.mitre.org/techniques/T1033/)
* [T1082](https://attack.mitre.org/techniques/T1082/)
* [T1083](https://attack.mitre.org/techniques/T1083/)
* [T1087](https://attack.mitre.org/techniques/T1087/)
* [T1120](https://attack.mitre.org/techniques/T1120/)
* [T1135](https://attack.mitre.org/techniques/T1135/)
* [T1016](https://attack.mitre.org/techniques/T1016/)
* [T1213](https://attack.mitre.org/techniques/T1213/)
* [T1573](https://attack.mitre.org/techniques/T1573/)
* [T1071](https://attack.mitre.org/techniques/T1071/)
* [T1102](https://attack.mitre.org/techniques/T1102/)
* [T1048](https://attack.mitre.org/techniques/T1048/)


December: The Crutch backdoor
-----------------------------


In December 2020,  a previously undocumented backdoor and document stealer named Crutch was [attributed to the Turla group](https://threatpost.com/turla-backdoor-dropbox-espionage-attacks/161777/). Apparently, older versions of Crutch included a backdoor that communicated with a hard-coded Dropbox account using the official HTTP API.


It had the ability to execute commands related to the reading and writing of files, executing additional processes, and setting persistence via DLL hijacking on Google Chrome, Mozilla Firefox, or Microsoft OneDrive. One major feature of Crutch v4 is that it can automatically upload the files found on local and removable drives to Dropbox storage by using the Windows version of the Wget utility (unlike the previous versions that relied on the backdoor commands).






[![Figure 6. The MITRE ATT&CK techniques used in Crutch attacks](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-06.jpg)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-06.jpg)

Figure 6. The MITRE ATT&CK techniques used in Crutch attacks







Techniques:


* [T1078.003](https://attack.mitre.org/versions/v7/techniques/T1078/003/)
* [T1053.005](https://attack.mitre.org/techniques/T1053/005/)
* [T1574.001](https://attack.mitre.org/techniques/T1574/001/)
* [T1036.004](https://attack.mitre.org/techniques/T1036/004/)
* [T1120](https://attack.mitre.org/techniques/T1120/)
* [T1025](https://attack.mitre.org/techniques/T1025)
* [T1074.001](https://attack.mitre.org/techniques/T1074/001/)
* [T1119](https://attack.mitre.org/techniques/T1119/)
* [1560.001](https://attack.mitre.org/techniques/T1560/001/)
* [T1008](https://attack.mitre.org/techniques/T1008/)
* [T1071.001](https://attack.mitre.org/techniques/T1071/001/)
* [T1102.002](https://attack.mitre.org/techniques/T1102/002/)
* [T1020](https://attack.mitre.org/techniques/T1020/)
* [T1041](https://attack.mitre.org/techniques/T1041/)
* [T1567.002](https://attack.mitre.org/techniques/T1567/002/)


2021
----


September: TinyTurla
--------------------


The new Turla backdoor known as [TinyTurla](https://blog.talosintelligence.com/tinyturla/) was likely used as a failover option to maintain access to the system even when the primary malware is removed. The backdoor is installed using a batch file and comes in the form of a service DLL called *w64time.dll* that tries to impersonate the legitimate *w32time.dll* file on Windows systems.


2022
----


May: Phishing-based reconnaissance campaign
-------------------------------------------


Turla’s May 2022 campaign was used for the sole purpose of reconnaissance and did not involve any use of malicious code. Security researchers [discovered a document](https://blog.sekoia.io/turla-new-phishing-campaign-eastern-europe/) that performed requests via HTTP to its own controlled server, with the purpose of capturing the version and type of Microsoft Word application used by the victim. The information can later be used to craft a specific exploit based on the Microsoft Word version.






[![Figure 7. The MITRE ATT&CK techniques used in the May 2022 reconnaissance campaign](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-07.jpg)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-07.jpg)

Figure 7. The MITRE ATT&CK techniques used in the May 2022 reconnaissance campaign







Techniques:


* [T1592.002](https://attack.mitre.org/techniques/T1592/002/)
* [T1590.005](https://attack.mitre.org/techniques/T1590/005/)
* [T1598.003](https://attack.mitre.org/techniques/T1598/003/)


2023
----


July: Attacks using Capibar and Kazuar
--------------------------------------


A July 2023 [announcement](https://cert.gov.ua/article/5213167) from the Computer Emergency Response Team of Ukraine (CERT-UA) revealed that Turla was using the Capibar malware and Kazuar backdoor for espionage attacks on Ukrainian defensive assets. In this campaign, Capibar was used for intelligence gathering while Kazuar performed credential theft. This attack targeted diplomatic and military organizations by leveraging phishing attacks. 






[![Figure 8. The MITRE ATT&CK techniques used in the July 2023 Capibar/Kazuar attacks](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-08.jpg)](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/Earth_Turla_mitre_table-08.jpg)

Figure 8. The MITRE ATT&CK techniques used in the July 2023 Capibar/Kazuar attacks







Techniques:


* [T1027](https://attack.mitre.org/techniques/T1027)
* [T1059](https://attack.mitre.org/techniques/T1059/)
* [T1053](https://attack.mitre.org/techniques/T1053/)
* [T1105](https://attack.mitre.org/techniques/T1105/)
* [T1567](https://attack.mitre.org/techniques/T1567/)
* [T1546](https://attack.mitre.org/techniques/T1546/)
* 


Conclusion
==========


The Turla group is a persistent adversary with a long history of activities. Their origins, tactics, and targets all indicate a well-funded operation with highly skilled operatives. Turla has continuously developed its tools and techniques over years and will likely keep on refining them.


The threat posed by groups such as Turla underscores the importance for organizations and governments to remain vigilant by staying informed, sharing intelligence, and implementing security measures that can allow both groups and individuals to better protect themselves against these kinds of threat actors.


Indicators of Compromise
========================


The indicators of compromise for the various Turla campaigns can be found [here](https://www.trendmicro.com/content/dam/trendmicro/global/en/research/23/i/examining-the-activities-of-the-turla-apt-group/ioc-examining-the-activities-of-the-turla-apt-group.txt).








## Tags:
***CVE's***: CVE-2013-3346 CVE-2012-1723 CVE-2013-5065
***MITRE IDs***: T1102.002 T1036.004 T1574.001 T1053.005 T1074.001 T1567.002 T1590.005 T1078.003 T1204.002 T1592.002 T1598.003 T1071.001

### Autogenerated tags:
turla kazuar windows malware att&ck backdoors second-stage microsoft c&c emails
